



clear all
close all
clc

%% 

%case parameters

p = 119                          %pressure (bar) 
tt=384.8
T = tt+273.15;

C0=219.8;                                      %concentration mg/kg
c_eq=20;           %equilibrium concentration mg/kg
deltaC=C0-c_eq;
%k_ag=1;                %stability factor (how many collisions result in attachment) 
%r_init=2.42e-10;             %critical radius

%measured deposition 
m_ab_14=0.7; %mg
m_cd_14=0.7; %mg
duration =134*60; %s
m_ab_dot=m_ab_14/duration; %mgsio2/s
m_cd_dot=m_cd_14/duration; %mgsio2/s

%test uncertainty
w_test_ab=1.117; %mg
w_test_cd=1.117; %mg
m_ab_max=m_ab_14+w_test_ab;
m_ab_min=0.00000001;
m_cd_max=m_cd_14+w_test_cd;
m_cd_min=0.000000001;
m_ab_dot_max=m_ab_max/duration; %mgsio2/s
m_ab_dot_min=m_ab_min/duration; %mgsio2/s
m_cd_dot_max=m_cd_max/duration; %mgsio2/s
m_cd_dot_min=m_cd_min/duration; %mgsio2/s

r_av_cd_SEM=1.5e-7
r_av_ab_SEM=r_av_cd_SEM/2
rmaxSEM=350e-9;     %nm     maximun observed particle size
rminSEM=50e-9;       %nm     minimum boserved particle size 

%test rig geometry
x_0=0.0404+0.0117;
D_pipe = 0.00138;            %Test chamber diameter (m) 
q = 10.3                 %mass flow in g/min or approximately ml/min of liquid water
Q1 = q/(60*1000);                %mass flow of water (kg/s)
L1_test=0.051;                 %length of test pipe (to be weighed)(m)
x=0.162;                          %section in front of test segment 
D_rod=0;                    %diameter of rod
n_rods=0;                   %number of rods
x_between=0.45;                 %length between test section 1 and 2
x2=x_between+x+L1_test;           %Section in front of test section 2 
L2_test=0.051;               %length of second test section 
x_final=0.348;                        %length between test section 2 and condenser
L_tot=x+L1_test+x_between+L2_test+x_final;       %total length 


%independent variable t
N1=100000;
t=logspace(-25,2,N1);

N2=30;      %number of groups

%Global constants
Vm=2.74e-5;              %m3/mol (molar volume)
V_M=4.54e-29;            %m3/molecule (molecular volume) 
R=8.314;                 %J/molK
gamma=0.092;             %J/m2
N_M=2e21;                %nucleation sites/total number of molecules
kb=1.3e-23;                 %boltzmann konstant J/K
etta=1;                   %turbulent dissipation m2/s3
roSiA=2196;                 %Amorphous silica density (kg/m3)


%calculated constants
visc = IAPWS_IF97('mu_pT',(p/10),T);                         %mu  - [Pa*s] viscosity mu_pT, IAPWS_IF97('mu_pT',p,T);
vs=IAPWS_IF97('v_pT',(p/10),T);                                 %spesific volume m3/kg
roW=1/vs;                                                          %density kg/m3
kinvisc=visc/roW;                                               %kinematic viscosity m2/s


V1 = Q1/roW;                                               %volumetric flow rate (m3/s)
A_cross = (pi*(D_pipe/2)^2);  %-(n_rods*pi*(D_rod/2)^2);       %cross sectional area of pipe (m2)
v = V1/A_cross                                              % Velocity (m/s) calculated based on test chamber diameter of D
D_hydr=D_pipe;     %(((pi*(D_pipe/2)^2)*L)-(n_rods*((pi*(D_rod/2)^2)*L)))/((2*pi*(D_pipe/2)*L)+(2*n_rods*pi*(D_rod/2)*L))              %hydraulic diameter (flow volume/wetted area)
Re = v*(D_hydr)/kinvisc       %Rynolds number (-)

h_ent=IAPWS_IF97('h_pT',(p/10),T); %enthalpy, h [kJ/kg]
cp=IAPWS_IF97('cp_ph',(p/10),h_ent); %Heat capasity at constant pressure [kJ/kg/K]
k_th=IAPWS_IF97('k_pT',(p/10),T);  %Thermal conductivity [W/m/K]

Pr=cp*1000*visc/k_th; % (-) OK dim

A_test=pi*D_pipe*L1_test;        %surface area in test chamber 
l_char=D_hydr; %Characteristic length. hydraulic diameter

frict=0.0791/(Re^0.25);         %friction factor- Fanning 
u_frict=v*sqrt(frict/2);           %frictional velocity (m/s)  

A_test_1=pi*D_pipe*L1_test;        %surface area in test chamber 
A_test_2=pi*D_pipe*L2_test;        %surface area in test chamber 

%size independent agglomeration kernels
beta_b_o=2*kb*T/(3*visc);        %process dependent brownian motion agglomeration kernel
beta_t_o=sqrt(etta/kinvisc);     %process dependent turbulent shear agglomeration kernel

%% Particle generation by classical nucleation theory

%dependent variables  

for i=1

c=zeros(1,N1);          %concentration of silicic acid in the solution
c_sio2=zeros(1,N1);      %concentration of solid silica in the solution

Gv=zeros(1,N1);         %Gibbs volume free enregy
                            %Gv(1)=(-R)*T*log(C/c_eq)/Vm;
r=zeros(1,N1);                  %radius of the nucleated colloids
                                   %r(1)=(-2*gamma)/(Gv(1));
V=zeros(1,N1);              %volume corresponding to critical radius
D_diff=zeros(1,N1);             %Diffusivity  
                                  %D_diff(1)=kb*T/(6*pi*r(1)*visc);
n=zeros(1,N1);                   %number of nucleus of critical size generated 
                                    %n(1)=t(1)*(sqrt(kb*T/gamma))*D_diff(1)*N_M*log(C/c_eq)/V_M*((C/c_eq)*exp(-(Gv(1)*((4/3)*pi*(r(1)^3)))+(gamma*(4*pi*(r(1)^2))))/(kb*T))/roW;
J=zeros(1,N1);
A=zeros(1,N1);
G_tot=zeros(1,N1);
V_p=zeros(1,N1);                %particle volume- assuming equal distribution
dn=zeros(1,N1);                     %added particles in each time step due to nucleation 
n_m=zeros(1,N1);                    %number of particles generated by nucleation per kg water
n_tm2=zeros(1,N1);                   %average number of particles per kg water- updated due to agglomeration- numerical

n_tV2=zeros(1,N1);          %updated number of particles in each time step- numerical solution_averaged   
r_t2=zeros(1,N1);           %updated average particle radius- numerical solution
dndt=zeros(1,N1);           %partial time derivative of number of particles in solution (reduction due to agglomeration)
V_p2=zeros(1,N1);        %volume per particle
m_p2=zeros(1,N1);        %mass per particle 
dc_sio2=zeros(1,N1);
dt=zeros(1,N1);             %time step
k_ag=ones(1,N1);           %stability for use in agglomeration and deposition (calculated in separate function)
end 

%time step
dt(1)=t(1);

for i=2:N1
    
    dt(i)=t(i)-t(i-1);
end

%% 

%solving concentration profile 

%initial conditions 

for i=1
 c(1)=C0;           %in reality valid for t=0- small error
 n(1)=0;            %number of nucleus generated in the first step (per cubic water)
 
 Gv(1)=(-R)*T*log(c(1)/c_eq)/Vm;
 r(1)=(-2*gamma)/(Gv(1));                                          %radius of particle generated in step 1 
 V(1)=(4*pi*(r(1)^3))/3;                                         %volume of particle generated in step 1
 G_tot(1)=(Gv(1)*((4/3)*pi*(r(1)^3)))+(gamma*(4*pi*(r(1)^2)));
 D_diff(1)=kb*T/(6*pi*r(1)*visc);
 A(1)=(sqrt(kb*T/gamma))*D_diff(1)*N_M*log(c(1)/c_eq)/V_M;
 J(1)=A(1)*(c(1)/c_eq)*exp(-G_tot(1)/(kb*T))*roW;
 dn(1)=J(1)*dt(1);

end 

for i=1:N1-1
    
           Gv(i)=(-R)*T*log(c(i)/c_eq)/Vm;
           r(i)=(-2*gamma)/(Gv(i));
           G_tot(i)=(Gv(i)*((4/3)*pi*(r(i)^3)))+(gamma*(4*pi*(r(i)^2)));
           D_diff(i)=kb*T/(6*pi*r(i)*visc);
           A(i)=(sqrt(kb*T/gamma))*D_diff(i)*N_M*log(c(i)/c_eq)/V_M;           %N_M defined as molecules/kg water gives nucleus/s per kg water
    
           J(i)=A(i)*(c(i)/c_eq)*exp(-G_tot(i)/(kb*T))*roW;                    %multiplied by roW to get nucleus per second per cubic of water
           V(i)=(4*pi*((r(i)^3)))/3;                         %volume of particle generated in step i
   
    
       if c_sio2(i)<(C0-c_eq)
        dn(i)=J(i)*dt(i);   %number of nucleus per cubic meter of water genreated in the time interval
            n(i+1)=n(i)+dn(i);                      %number of nucleus in the next step (per cubic water
            n_m(i+1)=n(i+1)/roW;                    %number of nucleus in the next step (per kg water)
            dc_sio2(i)=dn(i)*roSiA*V(i)*1000000/roW;
            c_sio2(i+1)=c_sio2(i)+dc_sio2(i);           %updated concentration of solid silica based on the number of particles generated in this step
            c(i+1)=C0-c_sio2(i+1);           %remaining concentration of silicic acid at step i given by mass balance.
                                                               %Change in concentration equals the total mass of added particles
       elseif c_sio2(i)>=C0-c_eq
           dn(i)=0;
              n(i+1)=n(i);
              n_m(i+1)=n_m(i);
              c_sio2(i+1)=C0-c_eq;
              c(i+1)=c_eq;
       end
       

    
end 
           

%%  %Agglomeration numerical
 
%defining constants
 C1=4*beta_b_o;         %assumin colliding particles are of equal size C1 is constant 
 C2=zeros(1,N1);

%Initial conditions 

for i=1:2
n_tV2(1)=n(1);
n_tV2(2)=n(2);

n_tm2(1)=n_tV2(1)/roW;
m_p2(1)= c_sio2(1)/(1000000*n_tm2(1));       %mass per particle kgSiO2/particle
V_p2(1)=m_p2(1)/roSiA;                       %volume per particle m3Sio2/particle 

r_t2(1)=r(1); 
C2(1)=0;

dndt(1)=k_ag(1)*(-0.5)*((C1*(n_tV2(1)^2))+(C2(1)*n_tV2(1))); 

end 

for i=2:N1-1
    
    if c_sio2(i)<(C0-c_eq)
        
    %k_ag(i)=stability_function(N1,r_t2(i-1));
    
    C2(i)=2*beta_t_o*(6/(pi))*c_sio2(i)*roW/(roSiA*1000000);
    dndt(i)=k_ag(i)*(-0.5)*((C1*(n_tV2(i)^2))+(C2(i)*n_tV2(i)));
    n_tV2(i+1)=n_tV2(i)+(dndt(i)*(dt(i)))+dn(i);
    n_tm2(i)=n_tV2(i)/roW; 
    m_p2(i)= c_sio2(i)/(1000000*n_tm2(i));                           %mass per particle kgSiO2/particle
    V_p2(i)= m_p2(i)/roSiA;                                          %volume per particle m3Sio2/particle 
    r_t2(i)=(V_p2(i)*3/(4*pi))^(1/3);                                  %new particle radius. (m)
 
    elseif c_sio2(i)>=(C0-c_eq)
        
    k_ag(i)=stability_function(N1,r_t2(i-1));
    
    C2(i)=2*beta_t_o*(6/(pi))*deltaC*roW/(roSiA*1000000);
    dndt(i)=k_ag(i)*(-0.5)*((C1*(n_tV2(i)^2))+(C2(i)*n_tV2(i)));
    n_tV2(i+1)=n_tV2(i)+(dndt_r(i)*(dt(i)));
    n_tm2(i)=n_tV2(i)/roW; 
    m_p2(i)= deltaC/(1000000*n_tm2(i));                           %mass per particle kgSiO2/particle
    V_p2(i)= m_p2(i)/roSiA;                                          %volume per particle m3Sio2/particle 
    r_t2(i)=(V_p2(i)*3/(4*pi))^(1/3);                                  %new particle radius. (m)
    
    end
end

k_ag(N1)=k_ag(N1-1);


%%
%agglomeration groups- class distribution 

%valiables
for i=1
 
Xn=zeros(N2,N1);        %number by concentration in each group matrix
Xnr=zeros(N2,N1);        %real number in each group matrix (different sizes)
Xc=zeros(N2,N1);        %concentration matrix
Xr=zeros(N2,N1);        %radius matrix
Xdn=zeros(N2,N1);       %change in particle number
Xdnout=zeros(N2,N1);    %particle number agglomerated out of each group 

Xctot=zeros(1,N1);     %total concentration in each time step (summarized by concentration in each particle size groups)
Xntot=zeros(1,N1);
Xntotr=zeros(1,N1);
XVp=zeros(1,N1);
Xr_av=zeros(1,N1);
XV1_=zeros(1,N1);

Xkag=ones(N2,N1);
Xcper=zeros(N2,N1);
Xnper=zeros(N2,N1);
Xcpertot=ones(1,N1);
Xnpertot=ones(1,N1);

XVr=zeros(N2,N1);
XVc=zeros(N2,N1);

Xravr=zeros(1,N1);
Xravc=zeros(1,N1);

Xcdep=zeros(N2,N1);

n_1r=zeros(1,N1);       %group 0- critical radius
n_2r=zeros(1,N1);       %group 1- doubled volume from group 0
n_4r=zeros(1,N1);       %group 2- doubled volume from group 1
n_8r=zeros(1,N1);       %group 3- doubled volume from group 2
n_16r=zeros(1,N1);      %group 4- doubled volume from group 3
n_32r=zeros(1,N1);      %group 5- doubled volume from group 4
n_64r=zeros(1,N1);      %group 6- doubled volume from group 5
n_128r=zeros(1,N1);     %group 7- doubled volume from group 6
n_256r=zeros(1,N1);     %group 8- doubled volume from group 7
n_512r=zeros(1,N1);     %group 9- doubled volume from group 8
n_1024r=zeros(1,N1);    %group 10- doubled volume from group 9
n_2048r=zeros(1,N1);     %group 7- doubled volume from group 6
n_4096r=zeros(1,N1);     %group 8- doubled volume from group 7
n_8192r=zeros(1,N1);     %group 9- doubled volume from group 8
n_16384r=zeros(1,N1);    %group 10- doubled volume from group 9
n_32768r=zeros(1,N1);     %group 9- doubled volume from group 8
n_65536r=zeros(1,N1);    %group 10- doubled volume from group 9
n_131072r=zeros(1,N1);     %group 7- doubled volume from group 6
n_262144r=zeros(1,N1);     %group 8- doubled volume from group 7
n_524288r=zeros(1,N1);     %group 9- doubled volume from group 8
n_1048576r=zeros(1,N1);    %group 10- doubled volume from group 9

n1c=zeros(1,N1);   %group 0- where particles are of equal size and number of particles is adjusted accordingly 
n2c=zeros(1,N1);   
n4c=zeros(1,N1);   
n8c=zeros(1,N1);   
n16c=zeros(1,N1);
n32c=zeros(1,N1);
n64c=zeros(1,N1);
n128c=zeros(1,N1);
n256c=zeros(1,N1);
n512c=zeros(1,N1);
n1024c=zeros(1,N1);
n2048c=zeros(1,N1);     %group 7- doubled volume from group 6
n4096c=zeros(1,N1);     %group 8- doubled volume from group 7
n8192c=zeros(1,N1);     %group 9- doubled volume from group 8
n16384c=zeros(1,N1);    %group 10- doubled volume from group 9
n32768c=zeros(1,N1);     %group 9- doubled volume from group 8
n65536c=zeros(1,N1);    %group 10- doubled volume from group 9
n131072c=zeros(1,N1);     %group 7- doubled volume from group 6
n262144c=zeros(1,N1);     %group 8- doubled volume from group 7
n524288c=zeros(1,N1);     %group 9- doubled volume from group 8
n1048576c=zeros(1,N1);    %group 10- doubled volume from group 9

c1=zeros(1,N1);
c2=zeros(1,N1);
c4=zeros(1,N1);
c8=zeros(1,N1);
c16=zeros(1,N1);
c32=zeros(1,N1);
c64=zeros(1,N1);
c128=zeros(1,N1);
c256=zeros(1,N1);
c512=zeros(1,N1);
c1024=zeros(1,N1);
c2048=zeros(1,N1);    
c4096=zeros(1,N1);     
c8192=zeros(1,N1);     
c16384=zeros(1,N1);
c32768=zeros(1,N1);     %group 9- doubled volume from group 8
c65536=zeros(1,N1);    %group 10- doubled volume from group 9
c131072=zeros(1,N1);     %group 7- doubled volume from group 6
c262144=zeros(1,N1);     %group 8- doubled volume from group 7
c524288=zeros(1,N1);     %group 9- doubled volume from group 8
c1048576=zeros(1,N1);    %group 10- doubled volume from group 9

r1_av=zeros(1,N1);

r2=zeros(1,N1);         % radius gorup 2
r4=zeros(1,N1);
r8=zeros(1,N1);
r16=zeros(1,N1);
r32=zeros(1,N1);
r64=zeros(1,N1);
r128=zeros(1,N1);
r256=zeros(1,N1);
r512=zeros(1,N1);
r1024=zeros(1,N1);
r2048=zeros(1,N1);    
r4096=zeros(1,N1);     
r8192=zeros(1,N1);     
r16384=zeros(1,N1);
r32768=zeros(1,N1);     %group 9- doubled volume from group 8
r65536=zeros(1,N1);    %group 10- doubled volume from group 9
r131072=zeros(1,N1);     %group 7- doubled volume from group 6
r262144=zeros(1,N1);     %group 8- doubled volume from group 7
r524288=zeros(1,N1);     %group 9- doubled volume from group 8
r1048576=zeros(1,N1);    %group 10- doubled volume from group 9

Vp1=zeros(1,N1);
Vp2=zeros(1,N1);
Vp4=zeros(1,N1);
Vp8=zeros(1,N1);
Vp16=zeros(1,N1);
Vp32=zeros(1,N1);
Vp64=zeros(1,N1);
Vp128=zeros(1,N1);
Vp256=zeros(1,N1);
Vp512=zeros(1,N1);
Vp1024=zeros(1,N1);
Vp2048=zeros(1,N1);    
Vp4096=zeros(1,N1);     
Vp8192=zeros(1,N1);     
Vp16384=zeros(1,N1);
Vp32768=zeros(1,N1);     %group 9- doubled volume from group 8
Vp65536=zeros(1,N1);    %group 10- doubled volume from group 9
Vp131072=zeros(1,N1);     %group 7- doubled volume from group 6
Vp262144=zeros(1,N1);     %group 8- doubled volume from group 7
Vp524288=zeros(1,N1);     %group 9- doubled volume from group 8
Vp1048576=zeros(1,N1);    %group 10- doubled volume from group 9

V_av_r=zeros(1,N1);
V_av_c=zeros(1,N1);

V1_=zeros(1,N1);            %total volume in group 1
r_av_r=zeros(1,N1);       %average radius  
r_av_c=zeros(1,N1);

c_tot=zeros(1,N1);     %total concentration (?)
c_tot_av=zeros(1,N1);

n_tot_r=zeros(1,N1);     %total number of particles. sum of all groups
n_tot_c=zeros(1,N1);     %total number of particles. sum of all groups

dn1dt=zeros(1,N1);      %gradient- change in number of particles in group 1 time derivative
dn2dt=zeros(1,N1);      %gradient- change in number of particles in group 2 time derivative
dn4dt=zeros(1,N1);      %gradient- change in number of particles in group 4 time derivative
dn8dt=zeros(1,N1);
dn16dt=zeros(1,N1);
dn32dt=zeros(1,N1);
dn64dt=zeros(1,N1);
dn128dt=zeros(1,N1);
dn256dt=zeros(1,N1);
dn512dt=zeros(1,N1);
dn1024dt=zeros(1,N1);
dn2048dt=zeros(1,N1);    
dn4096dt=zeros(1,N1);     
dn8192dt=zeros(1,N1);     
dn16384dt=zeros(1,N1);
dn32768dt=zeros(1,N1);
dn65536dt=zeros(1,N1);
dn131072dt=zeros(1,N1);    
dn262144dt=zeros(1,N1);     
dn524288dt=zeros(1,N1);     
dn1048576dt=zeros(1,N1);

dn1=zeros(1,N1);        %change in number of particles in group 1 in each time step. 
dn2=zeros(1,N1);
dn4=zeros(1,N1);
dn8=zeros(1,N1);
dn16=zeros(1,N1);
dn32=zeros(1,N1);
dn64=zeros(1,N1);
dn128=zeros(1,N1);
dn256=zeros(1,N1);
dn512=zeros(1,N1);
dn1024=zeros(1,N1);
dn2048=zeros(1,N1);    
dn4096=zeros(1,N1);     
dn8192=zeros(1,N1);     
dn16384=zeros(1,N1);
dn32768=zeros(1,N1);
dn65536=zeros(1,N1);
dn131072=zeros(1,N1);    
dn262144=zeros(1,N1);     
dn524288=zeros(1,N1);     
dn1048576=zeros(1,N1);

dn1_out=zeros(1,N1);
dn2_out=zeros(1,N1);
dn4_out=zeros(1,N1);
dn8_out=zeros(1,N1);
dn16_out=zeros(1,N1);
dn32_out=zeros(1,N1);
dn64_out=zeros(1,N1);
dn128_out=zeros(1,N1);
dn256_out=zeros(1,N1);
dn512_out=zeros(1,N1);
dn1024_out=zeros(1,N1);
dn2048_out=zeros(1,N1);    
dn4096_out=zeros(1,N1);     
dn8192_out=zeros(1,N1);     
dn16384_out=zeros(1,N1);
dn32768_out=zeros(1,N1);
dn65536_out=zeros(1,N1);
dn131072_out=zeros(1,N1);    
dn262144_out=zeros(1,N1);     
dn524288_out=zeros(1,N1);     
dn1048576_out=zeros(1,N1);

%establishing stability matrix

k_ag_1=ones(1,N1);
k_ag_2=ones(1,N1);
k_ag_4=ones(1,N1);
k_ag_8=ones(1,N1);
k_ag_16=ones(1,N1);
k_ag_32=ones(1,N1);
k_ag_64=ones(1,N1);
k_ag_128=ones(1,N1);
k_ag_256=ones(1,N1);
k_ag_512=ones(1,N1);
k_ag_1024=ones(1,N1);
k_ag_2048=ones(1,N1);    
k_ag_4096=ones(1,N1);     
k_ag_8192=ones(1,N1);     
k_ag_16384=ones(1,N1);
k_ag_32768=ones(1,N1);
k_ag_65536=ones(1,N1);
k_ag_131072=ones(1,N1);    
k_ag_262144=ones(1,N1);     
k_ag_524288=ones(1,N1);     
k_ag_1048576=ones(1,N1);
end 

%Initial conditions
for i=1:2
n_1r(1)=n_tV2(1);

r1_av(1)=r(1);
r2(1)=(2^(1/3))*r1_av(1);
r4(1)=(2^(1/3))*r2(1);
r8(1)=(2^(1/3))*r4(1);
r16(1)=(2^(1/3))*r8(1);
r32(1)=(2^(1/3))*r16(1);
r64(1)=(2^(1/3))*r32(1);
r128(1)=(2^(1/3))*r64(1);
r256(1)=(2^(1/3))*r128(1);
r512(1)=(2^(1/3))*r256(1);
r1024(1)=(2^(1/3))*r512(1);
r2048(1)=(2^(1/3))*r1024(1);   
r4096(1)=(2^(1/3))*r2048(1);    
r8192(1)=(2^(1/3))*r4096(1);    
r16384(1)=(2^(1/3))*r8192(1);
r32768(1)=(2^(1/3))*r16384(1);
r65536(1)=(2^(1/3))*r32768(1);
r131072(1)=(2^(1/3))*r65536(1);   
r262144(1)=(2^(1/3))*r131072(1);    
r524288(1)=(2^(1/3))*r262144(1);    
r1048576(1)=(2^(1/3))*r524288(1);

c1(1)=c_sio2(1);
c_tot(1)=c_sio2(1);

n1c(1)=c1(1)*roW*3/(4*pi*(r1_av(1)^3)*roSiA*1000000);  

dn1_out(1)=k_ag(1)*(((beta_b_o*4)+(beta_t_o*((4*r1_av(1))^3)))*(n_1r(1)^2))*dt(1);
dn2_out(1)=k_ag(1)*(((beta_b_o*4)+(beta_t_o*((4*r2(1))^3)))*(n_2r(1)^2))*dt(1);
dn4_out(1)=k_ag(1)*(((beta_b_o*4)+(beta_t_o*(((4*r4(1))^3))))*(n_4r(1)^2))*dt(1);
dn8_out(1)=k_ag(1)*(((beta_b_o*4)+(beta_t_o*((4*r8(1))^3)))*(n_8r(1)^2))*dt(1);
dn16_out(1)=k_ag(1)*(((beta_b_o*4)+(beta_t_o*((4*r16(1))^3)))*(n_16r(1)^2))*dt(1);
dn32_out(1)=k_ag(1)*(((beta_b_o*4)+(beta_t_o*(((4*r32(1))^3))))*(n_32r(1)^2))*dt(1);
dn64_out(1)=k_ag(1)*(((beta_b_o*4)+(beta_t_o*(((4*r64(1))^3))))*(n_64r(1)^2))*dt(1);
dn128_out(1)=k_ag(1)*(((beta_b_o*4)+(beta_t_o*((4*r128(1))^3)))*(n_128r(1)^2))*dt(1);
dn256_out(1)=k_ag(1)*(((beta_b_o*4)+(beta_t_o*(((4*r256(1))^3))))*(n_256r(1)^2))*dt(1);
dn512_out(1)=k_ag(1)*(((beta_b_o*4)+(beta_t_o*(((4*r512(1))^3))))*(n_512r(1)^2))*dt(1);
dn1024_out(1)=k_ag(1)*(((beta_b_o*4)+(beta_t_o*(((4*r1024(1))^3))))*(n_1024r(1)^2))*dt(1);
dn2048_out(1)=k_ag(1)*(((beta_b_o*4)+(beta_t_o*((4*r2048(1))^3)))*(n_2048r(1)^2))*dt(1);
dn4096_out(1)=k_ag(1)*(((beta_b_o*4)+(beta_t_o*(((4*r4096(1))^3))))*(n_4096r(1)^2))*dt(1);
dn8192_out(1)=k_ag(1)*(((beta_b_o*4)+(beta_t_o*(((4*r8192(1))^3))))*(n_8192r(1)^2))*dt(1);

dn1dt(1)=(dn(1)/dt(1))-...                                                           %inn gruppe 1
    k_ag(1)*(((beta_b_o*4)+(beta_t_o*((4*r1_av(1))^3)))*(n_1r(1)^2));                        %ut til gruppe 2
dn2dt(1)=k_ag(1)*(0.5)*(((beta_b_o*4)+(beta_t_o*((4*r1_av(1))^3)))*(n_1r(1)^2))-...          %inn gruppe 2
    k_ag(1)*(((beta_b_o*4)+(beta_t_o*((4*r2(1))^3)))*(n_2r(1)^2));                         %ut gruppe 4
dn4dt(1)=k_ag(1)*(0.5)*((beta_b_o*4)+(beta_t_o*((4*r2(1))^3)))*(n_2r(1)^2)-...                 %inn gruppe 4 fra gr 2
    k_ag(1)*(((beta_b_o*4)+(beta_t_o*(((4*r4(1))^3))))*(n_4r(1)^2));                               %ut gr 4 til gr 8
dn8dt(1)=k_ag(1)*(0.5)*((beta_b_o*4)+(beta_t_o*(((4*r4(1))^3))))*(n_4r(1)^2)-...                %inn gr 8 
    k_ag(1)*(((beta_b_o*4)+(beta_t_o*((4*r8(1))^3)))*(n_8r(1)^2));                                     %ut til gr 16
dn16dt(1)=k_ag(1)*(0.5)*(((beta_b_o*4)+(beta_t_o*(((4*r8(1))^3))))*(n_8r(1)^2))-...                 % inn til gr 16
    k_ag(1)*(((beta_b_o*4)+(beta_t_o*((4*r16(1))^3)))*(n_16r(1)^2));
dn32dt(1)=k_ag(1)*(0.5)*(((beta_b_o*4)+(beta_t_o*((4*r16(1))^3)))*(n_16r(1)^2))-...
    k_ag(1)*(((beta_b_o*4)+(beta_t_o*(((4*r32(1))^3))))*(n_32r(1)^2));
dn64dt(1)=k_ag(1)*(0.5)*(((beta_b_o*4)+(beta_t_o*(((4*r32(1))^3))))*(n_32r(1)^2))-...
    k_ag(1)*(((beta_b_o*4)+(beta_t_o*(((4*r64(1))^3))))*(n_64r(1)^2));
dn128dt(1)=(0.5)*dn64_out(1)/dt(1)-...
    dn128_out(1)/dt(1);
dn256dt(1)=(0.5)*dn128_out(1)/dt(1)-...
     dn256_out(1)/dt(1);
dn512dt(1)=(0.5)* dn256_out(1)/dt(1)-...
    dn512_out(1)/dt(1);
dn1024dt(1)=(0.5)*dn512_out(1)/dt(1)-...
    dn1024_out(1)/dt(1);  
dn2048dt(1)=(0.5)*dn1024_out(1)/dt(1)-...
    dn2048_out(1)/dt(1);
dn4096dt(1)=(0.5)*dn2048_out(1)/dt(1)-...
     dn4096_out(1)/dt(1);
dn8192dt(1)=(0.5)*dn4096_out(1)/dt(1)-...
     dn8192_out(1)/dt(1);
dn16384dt(1)=(0.5)* dn8192_out(1)/dt(1);  %partikler strre enn 163848 x opprinnelig kritisk volum

n_1r(2)=n_1r(1)+(dn1dt(1)*dt(1));
n_2r(2)=n_2r(1)+(dn2dt(1)*dt(1));
n_4r(2)=n_4r(1)+(dn4dt(1)*dt(1));
n_8r(2)=n_8r(1)+(dn8dt(1)*dt(1));
n_16r(2)=n_16r(1)+(dn16dt(1)*dt(1));
n_32r(2)=n_32r(1)+(dn32dt(1)*dt(1));
n_64r(2)=n_64r(1)+(dn64dt(1)*dt(1));
n_128r(2)=n_128r(1)+(dn128dt(1)*dt(1));
n_256r(2)=n_256r(1)+(dn256dt(1)*dt(1));
n_512r(2)=n_512r(1)+(dn512dt(1)*dt(1));
n_1024r(2)=n_1024r(1)+(dn1024dt(1)*dt(1));
n_2048r(2)=n_2048r(1)+(dn2048dt(1)*dt(1));
n_4096r(2)=n_4096r(1)+(dn4096dt(1)*dt(1));
n_8192r(2)=n_8192r(1)+(dn8192dt(1)*dt(1));
n_16384r(2)=n_16384r(1)+(dn16384dt(1)*dt(1));

V1_(1)=n_1r(1)*((4*pi)/3)*(r1_av(1)^3);                     %total volume of all particles in group 1 
V1_(2)=V1_(1)+(dn(1)*((4*pi)/3)*(r(1)^3));       %-(dn1_out(1)*4*pi*(r1_av(1)^3)/3);
r1_av(2)=(V1_(2)*3/(4*pi*n_1r(2)))^(1/3);                                 %average radius of one particle in group 1
V_tot_av(1)=V1_(1);

c1(1)=c_sio2(1);
c_tot(1)=c_sio2(1);
end 

%filling matrixes
for i=2:N1-1

r2(i)=(2^(1/3))*r1_av(i);               %|
r4(i)=(2^(1/3))*r2(i);                  %2
r8(i)=(2^(1/3))*r4(i);                  %3
r16(i)=(2^(1/3))*r8(i);                 %4
r32(i)=(2^(1/3))*r16(i);                %5
r64(i)=(2^(1/3))*r32(i);                %6
r128(i)=(2^(1/3))*r64(i);               %7
r256(i)=(2^(1/3))*r128(i);              %8
r512(i)=(2^(1/3))*r256(i);              %9
r1024(i)=(2^(1/3))*r512(i);             %10
r2048(i)=(2^(1/3))*r1024(i);            %11
r4096(i)=(2^(1/3))*r2048(i);            %12
r8192(i)=(2^(1/3))*r4096(i);            %13
r16384(i)=(2^(1/3))*r8192(i);           %14
r32768(i)=(2^(1/3))*r16384(i);          %15
r65536(i)=(2^(1/3))*r32768(i);          %16
r131072(i)=(2^(1/3))*r65536(i);         %17
r262144(i)=(2^(1/3))*r131072(i);        %18
r524288(i)=(2^(1/3))*r262144(i);        %19
r1048576(i)=(2^(1/3))*r524288(i);       %20

%k_ag_1(i)=stability_function(N1,r1_av(i));
%k_ag_2(i)=stability_function(N1,r2(i));
%k_ag_4(i)=stability_function(N1,r4(i));
%k_ag_8(i)=stability_function(N1,r8(i));
%k_ag_16(i)=stability_function(N1,r16(i));
%k_ag_32(i)=stability_function(N1,r32(i));
%k_ag_64(i)=stability_function(N1,r64(i));
%k_ag_128(i)=stability_function(N1,r128(i));
%k_ag_256(i)=stability_function(N1,r256(i));
%k_ag_512(i)=stability_function(N1,r512(i));
%k_ag_1024(i)=stability_function(N1,r1024(i));
%k_ag_2048(i)=stability_function(N1,r2048(i));    
%k_ag_4096(i)=stability_function(N1,r4096(i));     
%k_ag_8192(i)=stability_function(N1,r8192(i));     
%k_ag_16384(i)=stability_function(N1,r16384(i));
%k_ag_32768(i)=stability_function(N1,r32768(i));
%k_ag_65536(i)=stability_function(N1,r65536(i));
%k_ag_131072(i)=stability_function(N1,r131072(i));    
%k_ag_262144(i)=stability_function(N1,r262144(i));     
%k_ag_524288(i)=stability_function(N1,r524288(i));     
%k_ag_1048576(i)=stability_function(N1,r1048576(i));

Vp1(i)=(4*pi)*(r1_av(i)^3)/3;
Vp2(i)=(4*pi)*(r2(i)^3)/3;
Vp4(i)=(4*pi)*(r4(i)^3)/3;
Vp8(i)=(4*pi)*(r8(i)^3)/3;
Vp16(i)=(4*pi)*(r16(i)^3)/3;
Vp32(i)=(4*pi)*(r32(i)^3)/3;
Vp64(i)=(4*pi)*(r64(i)^3)/3;
Vp128(i)=(4*pi)*(r128(i)^3)/3;
Vp256(i)=(4*pi)*(r256(i)^3)/3;
Vp512(i)=(4*pi)*(r512(i)^3)/3;
Vp1024(i)=(4*pi)*(r1024(i)^3)/3;
Vp2048(i)=(4*pi)*(r2048(i)^3)/3;
Vp4096(i)=(4*pi)*(r4096(i)^3)/3;
Vp8192(i)=(4*pi)*(r8192(i)^3)/3;
Vp16384(i)=(4*pi)*(r16384(i)^3)/3;
Vp32768(i)=(4*pi)*(r32768(i)^3)/3;
Vp65536(i)=(4*pi)*(r65536(i)^3)/3;
Vp131072(i)=(4*pi)*(r131072(i)^3)/3;
Vp262144(i)=(4*pi)*(r262144(i)^3)/3;
Vp524288(i)=(4*pi)*(r524288(i)^3)/3;
Vp1048576(i)=(4*pi)*(r1048576(i)^3)/3;

c1(i)=c1(i-1)+((dn(i-1)*(r(i-1)^3))-(dn1_out(i-1)*(r1_av(i-1)^3)))*(((4*pi)/3)*roSiA/roW)*1000000;
c2(i)=c2(i-1)+((dn2dt(i-1)*dt(i-1))*(r2(i-1)^3)*(((4*pi)/3)*roSiA/roW)*1000000);
c4(i)=c4(i-1)+((dn4dt(i-1)*dt(i-1))*(r4(i-1)^3)*(((4*pi)/3)*roSiA/roW)*1000000);
c8(i)=c8(i-1)+((dn8dt(i-1)*dt(i-1))*(r8(i-1)^3)*(((4*pi)/3)*roSiA/roW)*1000000);
c16(i)=c16(i-1)+((dn16dt(i-1)*dt(i-1))*(r16(i-1)^3)*(((4*pi)/3)*roSiA/roW)*1000000);
c32(i)=c32(i-1)+((dn32dt(i-1)*dt(i-1))*(r32(i-1)^3)*(((4*pi)/3)*roSiA/roW)*1000000);
c64(i)=c64(i-1)+((dn64dt(i-1)*dt(i-1))*(r64(i-1)^3)*(((4*pi)/3)*roSiA/roW)*1000000);
c128(i)=c128(i-1)+((dn128dt(i-1)*dt(i-1))*(r128(i-1)^3)*(((4*pi)/3)*roSiA/roW)*1000000);
c256(i)=c256(i-1)+((dn256dt(i-1)*dt(i-1))*(r256(i-1)^3)*(((4*pi)/3)*roSiA/roW)*1000000);
c512(i)=c512(i-1)+((dn512dt(i-1)*dt(i-1))*(r512(i-1)^3)*(((4*pi)/3)*roSiA/roW)*1000000);
c1024(i)=c1024(i-1)+((dn1024dt(i-1)*dt(i-1))*(r1024(i-1)^3)*(((4*pi)/3)*roSiA/roW)*1000000);
c2048(i)=c2048(i-1)+((dn2048dt(i-1)*dt(i-1))*(r2048(i-1)^3)*(((4*pi)/3)*roSiA/roW)*1000000);
c4096(i)=c4096(i-1)+((dn4096dt(i-1)*dt(i-1))*(r4096(i-1)^3)*(((4*pi)/3)*roSiA/roW)*1000000);
c8192(i)=c8192(i-1)+((dn8192dt(i-1)*dt(i-1))*(r8192(i-1)^3)*(((4*pi)/3)*roSiA/roW)*1000000);
c16384(i)=c16384(i-1)+((dn16384dt(i-1)*dt(i-1))*(r16384(i-1)^3)*(((4*pi)/3)*roSiA/roW)*1000000);
c32768(i)=c32768(i-1)+((dn32768dt(i-1)*dt(i-1))*(r32768(i-1)^3)*(((4*pi)/3)*roSiA/roW)*1000000);
c65536(i)=c65536(i-1)+((dn65536dt(i-1)*dt(i-1))*(r65536(i-1)^3)*(((4*pi)/3)*roSiA/roW)*1000000);
c131072(i)=c131072(i-1)+((dn131072dt(i-1)*dt(i-1))*(r131072(i-1)^3)*(((4*pi)/3)*roSiA/roW)*1000000);
c262144(i)=c262144(i-1)+((dn262144dt(i-1)*dt(i-1))*(r262144(i-1)^3)*(((4*pi)/3)*roSiA/roW)*1000000);
c524288(i)=c524288(i-1)+((dn524288dt(i-1)*dt(i-1))*(r524288(i-1)^3)*(((4*pi)/3)*roSiA/roW)*1000000);
c1048576(i)=c1048576(i-1)+((dn1048576dt(i-1)*dt(i-1))*(r1048576(i-1)^3)*(((4*pi)/3)*roSiA/roW)*1000000);

c_tot(i)=c1(i)+c2(i)+c4(i)+c8(i)+c16(i)+c32(i)+c64(i)+c128(i)+c256(i)+...
    c512(i)+c1024(i)+c2048(i)+c4096(i)+c8192(i)+c16384(i)+...
    c32768(i)+c65536(i)+c131072(i)+c262144(i)+c524288(i)+c1048576(i);             %fr negative verdier for noen av konsentrasjonene

n1c(i)=c1(i)*roW/(Vp1(i)*roSiA*1000000);             %*(r9(i-1)^3)*(((4*pi)/3)*roSiA/roW)*1000000)))
n2c(i)=c2(i)*roW/(Vp2(i)*roSiA*1000000);  
n4c(i)=c4(i)*roW/(Vp4(i)*roSiA*1000000);
n8c(i)=c8(i)*roW/(Vp8(i)*roSiA*1000000);
n16c(i)=c16(i)*roW/(Vp16(i)*roSiA*1000000);
n32c(i)=c32(i)*roW/(Vp32(i)*roSiA*1000000);  
n64c(i)=c64(i)*roW/(Vp64(i)*roSiA*1000000);
n128c(i)=c128(i)*roW/(Vp128(i)*roSiA*1000000);  
n256c(i)=c256(i)*roW/(Vp256(i)*roSiA*1000000);  
n512c(i)=c512(i)*roW/(Vp512(i)*roSiA*1000000);  
n1024c(i)=c1024(i)*roW/(Vp1024(i)*roSiA*1000000);
n2048c(i)=c2048(i)*roW/(Vp2048(i)*roSiA*1000000);  
n4096c(i)=c4096(i)*roW/(Vp4096(i)*roSiA*1000000);  
n8192c(i)=c8192(i)*roW/(Vp8192(i)*roSiA*1000000);  
n16384c(i)=c16384(i)*roW/(Vp16384(i)*roSiA*1000000);
n32768c(i)=c32768(i)*roW/(Vp32768(i)*roSiA*1000000);  
n65536c(i)=c65536(i)*roW/(Vp65536(i)*roSiA*1000000);
n131072c(i)=c131072(i)*roW/(Vp131072(i)*roSiA*1000000);  
n262144c(i)=c262144(i)*roW/(Vp262144(i)*roSiA*1000000);  
n524288c(i)=c524288(i)*roW/(Vp524288(i)*roSiA*1000000);  
n1048576c(i)=c1048576(i)*roW/(Vp1048576(i)*roSiA*1000000);

if c1(i)>0
    dn1_out(i)=k_ag_1(i)*(((beta_b_o*4)+(beta_t_o*((4*r1_av(i))^3)))*(n1c(i)^2))*dt(i); 
else 
    dn1_out(i)=0;
end
  
if c2(i)>0
   dn2_out(i)=k_ag_2(i)*(((beta_b_o*4)+(beta_t_o*((4*r2(i))^3)))*(n2c(i)^2))*dt(i);
else
    dn2_out(i)=0;
end

if c4(i)>0
   dn4_out(i)=k_ag_4(i)*(((beta_b_o*4)+(beta_t_o*(((4*r4(i))^3))))*(n4c(i)^2))*dt(i);
else
    dn4_out(i)=0;
end

if c8(i)>0
   dn8_out(i)=k_ag_8(i)*(((beta_b_o*4)+(beta_t_o*((4*r8(i))^3)))*(n8c(i)^2))*dt(i);
else
    dn8_out(i)=0;
end

if c16(i)>0
   dn16_out(i)=k_ag_16(i)*(((beta_b_o*4)+(beta_t_o*((4*r16(i))^3)))*(n16c(i)^2))*dt(i);
else
    dn16_out(i)=0;
end

if c32(i)>0
   dn32_out(i)=k_ag_32(i)*(((beta_b_o*4)+(beta_t_o*(((4*r32(i))^3))))*(n32c(i)^2))*dt(i);
else
    dn32_out(i)=0;
end

if c64(i)>0
   dn64_out(i)=k_ag_64(i)*(((beta_b_o*4)+(beta_t_o*(((4*r64(i))^3))))*(n64c(i)^2))*dt(i);
else
    dn64_out(i)=0;
end

if c128(i)>0
   dn128_out(i)=k_ag_128(i)*(((beta_b_o*4)+(beta_t_o*((4*r128(i))^3)))*(n128c(i)^2))*dt(i);
else
    dn128_out(i)=0;
end

if c256(i)>0
   dn256_out(i)=k_ag_256(i)*(((beta_b_o*4)+(beta_t_o*(((4*r256(i))^3))))*(n256c(i)^2))*dt(i);
else
    dn256_out(i)=0;
end

if c512(i)>0
   dn512_out(i)=k_ag_512(i)*(((beta_b_o*4)+(beta_t_o*(((4*r512(i))^3))))*(n512c(i)^2))*dt(i);
else
    dn512_out(i)=0;
end

if c1024(i)>0
   dn1024_out(i)=k_ag_1024(i)*(((beta_b_o*4)+(beta_t_o*((4*r1024(i))^3)))*(n1024c(i)^2))*dt(i);
else
    dn1024_out(i)=0;
end

if c2048(i)>0
   dn2048_out(i)=k_ag_2048(i)*(((beta_b_o*4)+(beta_t_o*(((4*r2048(i))^3))))*(n2048c(i)^2))*dt(i);
else
    dn2048_out(i)=0;
end

if c4096(i)>0
   dn4096_out(i)=k_ag_4096(i)*(((beta_b_o*4)+(beta_t_o*(((4*r4096(i))^3))))*(n4096c(i)^2))*dt(i);
else
    dn4096_out(i)=0;
end

if c8192(i)>0
   dn8192_out(i)=k_ag_8192(i)*(((beta_b_o*4)+(beta_t_o*(((4*r8192(i))^3))))*(n8192c(i)^2))*dt(i);
else
    dn8192_out(i)=0;
end

if c16384(i)>0
   dn16384_out(i)=k_ag_16384(i)*(((beta_b_o*4)+(beta_t_o*(((4*r16384(i))^3))))*(n16384c(i)^2))*dt(i);
else
    dn16384_out(i)=0;
end

if c32768(i)>0
   dn32768_out(i)=k_ag_32768(i)*(((beta_b_o*4)+(beta_t_o*(((4*r32768(i))^3))))*(n32768c(i)^2))*dt(i);
else
    dn32768_out(i)=0;
end

if c65536(i)>0
   dn65536_out(i)=k_ag_65536(i)*(((beta_b_o*4)+(beta_t_o*((4*r65536(i))^3)))*(n65536c(i)^2))*dt(i);
else
    dn65536_out(i)=0;
end

if c131072(i)>0
   dn131072_out(i)=k_ag_131072(i)*(((beta_b_o*4)+(beta_t_o*(((4*r131072(i))^3))))*(n131072c(i)^2))*dt(i);
else
    dn131072_out(i)=0;
end

if c262144(i)>0
   dn262144_out(i)=k_ag_262144(i)*(((beta_b_o*4)+(beta_t_o*(((4*r262144(i))^3))))*(n262144c(i)^2))*dt(i);
else
    dn262144_out(i)=0;
end

if c524288(i)>0
   dn524288_out(i)=k_ag_524288(i)*(((beta_b_o*4)+(beta_t_o*(((4*r524288(i))^3))))*(n524288c(i)^2))*dt(i);
else
    dn524288_out(i)=0;
end

if c1048576(i)>0
   dn1048576_out(i)=k_ag_1048576(i)*(((beta_b_o*4)+(beta_t_o*(((4*r1048576(i))^3))))*(n1048576c(i)^2))*dt(i);
else
    dn1048576_out(i)=0;
end

dn1dt(i)=(dn(i)/dt(i))-...                                                           %inn gruppe 1
    (dn1_out(i)/dt(i));                        %ut til gruppe 2
dn2dt(i)=(0.5)*dn1_out(i)/dt(i)-...          %inn gruppe 2
    dn2_out(i)/dt(i);                           %ut gruppe 4
dn4dt(i)=(0.5)*dn2_out(i)/dt(i)-...                 %inn gruppe 4 fra gr 2
    dn4_out(i)/dt(i);                            %ut gr 4 til gr 8
dn8dt(i)=(0.5)*dn4_out(i)/dt(i)-...                %inn gr 8 
    dn8_out(i)/dt(i);                              %ut til gr 16
dn16dt(i)=(0.5)*dn8_out(i)/dt(i)-...             % inn til gr 16
    dn16_out(i)/dt(i);
dn32dt(i)=(0.5)*dn16_out(i)/dt(i)-...
     dn32_out(i)/dt(i);
dn64dt(i)=(0.5)*dn32_out(i)/dt(i)-...
    dn64_out(i)/dt(i);
dn128dt(i)=(0.5)*dn64_out(i)/dt(i)-...
    dn128_out(i)/dt(i);
dn256dt(i)=(0.5)*dn128_out(i)/dt(i)-...
     dn256_out(i)/dt(i);
dn512dt(i)=(0.5)* dn256_out(i)/dt(i)-...
    dn512_out(i)/dt(i);
dn1024dt(i)=(0.5)*dn512_out(i)/dt(i)-...
    dn1024_out(i)/dt(i);
dn2048dt(i)=(0.5)*dn1024_out(i)/dt(i)-...
    dn2048_out(i)/dt(i);
dn4096dt(i)=(0.5)*dn2048_out(i)/dt(i)-...
     dn4096_out(i)/dt(i);
dn8192dt(i)=(0.5)* dn4096_out(i)/dt(i)-...
    dn8192_out(i)/dt(i);
dn16384dt(i)=(0.5)*dn8192_out(i)/dt(i)-...
    dn16384_out(i)/dt(i);
dn32768dt(i)=(0.5)* dn16384_out(i)/dt(i)-...
    dn32768_out(i)/dt(i);
dn65536dt(i)=(0.5)*dn32768_out(i)/dt(i)-...
    dn65536_out(i)/dt(i);
dn131072dt(i)=(0.5)*dn65536_out(i)/dt(i)-...
    dn131072_out(i)/dt(i);
dn262144dt(i)=(0.5)*dn131072_out(i)/dt(i)-...
     dn262144_out(i)/dt(i);
dn524288dt(i)=(0.5)* dn262144_out(i)/dt(i)-...
    dn524288_out(i)/dt(i);
dn1048576dt(i)=(0.5)*dn524288_out(i)/dt(i);

dn1(i)=(dn1dt(i)*dt(i));
dn2(i)=(dn2dt(i)*dt(i));
dn4(i)=(dn4dt(i)*dt(i));
dn8(i)=(dn8dt(i)*dt(i));
dn16(i)=(dn16dt(i)*dt(i));
dn32(i)=(dn32dt(i)*dt(i));
dn64(i)=(dn64dt(i)*dt(i));
dn128(i)=(dn128dt(i)*dt(i));
dn256(i)=(dn256dt(i)*dt(i));
dn512(i)=(dn512dt(i)*dt(i));
dn1024(i)=(dn1024dt(i)*dt(i));
dn2048(i)=(dn2048dt(i)*dt(i));
dn4096(i)=(dn4096dt(i)*dt(i));
dn8192(i)=(dn8192dt(i)*dt(i));
dn16384(i)=(dn16384dt(i)*dt(i));
dn32768(i)=(dn32768dt(i)*dt(i));
dn65536(i)=(dn65536dt(i)*dt(i));
dn131072(i)=(dn131072dt(i)*dt(i));
dn262144(i)=(dn262144dt(i)*dt(i));
dn524288(i)=(dn524288dt(i)*dt(i));
dn1048576(i)=(dn1048576dt(i)*dt(i));

%real number of particles counting additions where the earlier particles
%are smaller than the once recently added. 
    n_1r(i+1)=n_1r(i)+(dn1dt(i)*dt(i));
    n_2r(i+1)=n_2r(i)+(dn2dt(i)*dt(i));
    n_4r(i+1)=n_4r(i)+(dn4dt(i)*dt(i));
    n_8r(i+1)=n_8r(i)+(dn8dt(i)*dt(i));
    n_16r(i+1)=n_16r(i)+(dn16dt(i)*dt(i));
    n_32r(i+1)=n_32r(i)+(dn32dt(i)*dt(i));
    n_64r(i+1)=n_64r(i)+(dn64dt(i)*dt(i));
    n_128r(i+1)=n_128r(i)+(dn128dt(i)*dt(i));
    n_256r(i+1)=n_256r(i)+(dn256dt(i)*dt(i));
    n_512r(i+1)=n_512r(i)+(dn512dt(i)*dt(i));
    n_1024r(i+1)=n_1024r(i)+(dn1024dt(i)*dt(i));
    n_2048r(i+1)=n_2048r(i)+(dn2048dt(i)*dt(i));
    n_4096r(i+1)=n_4096r(i)+(dn4096dt(i)*dt(i));
    n_8192r(i+1)=n_8192r(i)+(dn8192dt(i)*dt(i));
    n_16384r(i+1)=n_16384r(i)+(dn16384dt(i)*dt(i));
    n_32768r(i+1)=n_32768r(i)+(dn32768dt(i)*dt(i));
    n_65536r(i+1)=n_65536r(i)+(dn65536dt(i)*dt(i));
    n_131072r(i+1)=n_131072r(i)+(dn131072dt(i)*dt(i));
    n_262144r(i+1)=n_262144r(i)+(dn262144dt(i)*dt(i));
    n_524288r(i+1)=n_524288r(i)+(dn524288dt(i)*dt(i));
    n_1048576r(i+1)=n_1048576r(i)+(dn1048576dt(i)*dt(i));

%Total volume of added particles with negative value condition 
if (V1_(i)+(dn(i)*V(i)))>(dn1_out(i)*(V1_(i)/n_1r(i)))
    V1_(i+1)=V1_(i)+(dn(i)*V(i))-(dn1_out(i)*(V1_(i)/n_1r(i)));                 
else
    V1_(i+1)=0;
end

r1_av(i+1)=(V1_(i+1)*3/(4*pi*n_1r(i+1)))^(1/3); %average radius of one particle


n_tot_r(i)=n_1r(i)+n_2r(i)+n_4r(i)+n_8r(i)+n_16r(i)+n_32r(i)+n_64r(i)+n_128r(i)+...
            n_256r(i)+n_512r(i)+n_1024r(i)+n_2048r(i)+n_4096r(i)+n_8192r(i)+n_16384r(i)+...
            +n_32768r(i)+n_65536r(i)+n_131072r(i)+n_262144r(i)+n_524288r(i)+n_1048576r(i);

n_tot_c(i)=n1c(i)+n2c(i)+n4c(i)+n8c(i)+n16c(i)+n32c(i)+n64c(i)+n128c(i)+...
           n256c(i)+n512c(i)+n1024c(i)+n2048c(i)+n4096c(i)+n8192c(i)+n16384c(i)+...
           +n32768c(i)+n65536c(i)+n131072c(i)+n262144c(i)+n524288c(i)+n1048576c(i);

V_av_r(i)=(4*pi/3)*((n_1r(i)*(r1_av(i)^3))+(n_2r(i)*(r2(i)^3))+(n_4r(i)*(r4(i)^3))+(n_8r(i)*(r8(i)^3))+...
    (n_16r(i)*(r16(i)^3))+(n_32r(i)*(r32(i)^3))+(n_64r(i)*(r64(i)^3))+(n_128r(i)*(r128(i)^3))+...
    (n_256r(i)*(r256(i)^3))+(n_512r(i)*(r512(i)^3))+(n_1024r(i)*(r1024(i)^3))+(n_2048r(i)*(r2048(i)^3))+...
    (n_4096r(i)*(r4096(i)^3))+(n_8192r(i)*(r8192(i)^3))+(n_16384r(i)*(r16384(i)^3))+...
    +(n_32768r(i)*(r32768(i)^3))+(n_65536r(i)*(r65536(i)^3))+(n_131072r(i)*(r131072(i)^3))+...
    (n_262144r(i)*(r262144(i)^3))+(n_524288r(i)*(r524288(i)^3))+(n_1048576r(i)*(r1048576(i)^3)))/n_tot_r(i);

V_av_c(i)=(4*pi/3)*((n1c(i)*(r1_av(i)^3))+(n2c(i)*(r2(i)^3))+(n4c(i)*(r4(i)^3))+(n8c(i)*(r8(i)^3))+...
    (n16c(i)*(r16(i)^3))+(n32c(i)*(r32(i)^3))+(n64c(i)*(r64(i)^3))+(n128c(i)*(r128(i)^3))+...
    (n256c(i)*(r256(i)^3))+(n512c(i)*(r512(i)^3))+(n1024c(i)*(r1024(i)^3))+(n2048c(i)*(r2048(i)^3))+...
    (n4096c(i)*(r4096(i)^3))+(n8192c(i)*(r8192(i)^3))+(n16384c(i)*(r16384(i)^3))+...
    +(n32768c(i)*(r32768(i)^3))+(n65536c(i)*(r65536(i)^3))+(n131072c(i)*(r131072(i)^3))+...
    (n262144c(i)*(r262144(i)^3))+(n524288c(i)*(r524288(i)^3))+(n1048576c(i)*(r1048576(i)^3)))/n_tot_c(i);

r_av_r(i)=(V_av_r(i)*(3/(4*pi)))^(1/3);
r_av_c(i)=(V_av_c(i)*(3/(4*pi)))^(1/3);


end

%last step- final condition
for i=N1
if (dn1dt(N1)*dt(N1))<n_1r(N1)
dn1_out(N1)=(((beta_b_o*4)+(beta_t_o*((4*r1_av(N1))^3)))*(n_1r(N1)^2))*dt(N1); 
elseif (dn1dt(N1)*dt(N1))>=n_1r(N1)
    dn1_out(N1)=0;
end
  
if (dn2dt(N1)*dt(i))<n_2r(N1)
   dn2_out(N1)=(((beta_b_o*4)+(beta_t_o*((4*r2(N1))^3)))*(n_2r(N1)^2))*dt(N1);
elseif (dn2dt(N1)*dt(N1))>=n_2r(N1)
    dn2_out(N1)=0;
end

if (dn4dt(N1)*dt(N1))<n_4r(N1)
   dn4_out(N1)=(((beta_b_o*4)+(beta_t_o*(((4*r4(N1))^3))))*(n_4r(N1)^2))*dt(N1);
elseif (dn4dt(N1)*dt(N1))>=n_4r(N1)
    dn4_out(N1)=0;
end

if (dn8dt(N1)*dt(N1))<n_8r(N1)
   dn8_out(N1)=(((beta_b_o*4)+(beta_t_o*((4*r8(N1))^3)))*(n_8r(N1)^2))*dt(N1);
elseif (dn8dt(N1)*dt(N1))>=n_8r(N1)
    dn8_out(N1)=0;
end

if (dn16dt(N1)*dt(N1))<n_16r(N1)
   dn16_out(N1)=(((beta_b_o*4)+(beta_t_o*((4*r16(N1))^3)))*(n_16r(N1)^2))*dt(N1);
elseif (dn16dt(N1)*dt(N1))>=n_16r(N1)
    dn16_out(N1)=0;
end

if (dn32dt(N1)*dt(N1))<n_32r(N1)
   dn32_out(N1)=(((beta_b_o*4)+(beta_t_o*(((4*r32(N1))^3))))*(n_32r(N1)^2))*dt(N1);
elseif (dn32dt(N1)*dt(N1))>=n_32r(N1)
    dn32_out(N1)=0;
end

if (dn64dt(N1)*dt(N1))<n_64r(N1)
   dn64_out(N1)=(((beta_b_o*4)+(beta_t_o*(((4*r64(N1))^3))))*(n_64r(N1)^2))*dt(N1);
elseif (dn64dt(N1)*dt(N1-1))>=n_64r(N1)
    dn64_out(N1)=0;
end

if (dn128dt(N1)*dt(N1))<n_128r(N1)
   dn128_out(N1)=(((beta_b_o*4)+(beta_t_o*((4*r128(N1))^3)))*(n_128r(N1)^2))*dt(N1);
elseif (dn128dt(N1)*dt(N1))>=n_128r(N1)
    dn128_out(N1)=0;
end

if (dn256dt(N1)*dt(N1))<n_256r(N1)
   dn256_out(N1)=(((beta_b_o*4)+(beta_t_o*((4*r256(N1))^3)))*(n_256r(N1)^2))*dt(N1);
elseif (dn256dt(N1)*dt(N1))>=n_256r(N1)
    dn256_out(N1)=0;
end

if (dn512dt(N1)*dt(N1))<n_512r(N1)
   dn512_out(N1)=(((beta_b_o*4)+(beta_t_o*(((4*r512(N1))^3))))*(n_512r(N1)^2))*dt(N1);
elseif (dn512dt(N1)*dt(N1))>=n_512r(N1)
    dn512_out(N1)=0;
end

if (dn1024dt(N1)*dt(N1))<n_1024r(N1)
   dn1024_out(N1)=(((beta_b_o*4)+(beta_t_o*(((4*r1024(N1))^3))))*(n_1024r(N1)^2))*dt(N1);
elseif (dn1024dt(N1)*dt(N1-1))>=n_1024r(N1)
    dn1024_out(N1)=0;
end

if (dn2048dt(N1)*dt(N1))<n_2048r(N1)
   dn2048_out(N1)=(((beta_b_o*4)+(beta_t_o*((4*r2048(N1))^3)))*(n_2048r(N1)^2))*dt(N1);
elseif (dn2048dt(N1)*dt(N1))>=n_2048r(N1)
    dn2048_out(N1)=0;
end

if (dn4096dt(N1)*dt(N1))<n_4096r(N1)
   dn4096_out(N1)=(((beta_b_o*4)+(beta_t_o*((4*r4096(N1))^3)))*(n_4096r(N1)^2))*dt(N1);
elseif (dn4096dt(N1)*dt(N1))>=n_4096r(N1)
    dn4096_out(N1)=0;
end

if (dn8192dt(N1)*dt(N1))<n_8192r(N1)
   dn8192_out(N1)=(((beta_b_o*4)+(beta_t_o*(((4*r8192(N1))^3))))*(n_8192r(N1)^2))*dt(N1);
elseif (dn8192dt(N1)*dt(N1))>=n_8192r(N1)
    dn8192_out(N1)=0;
end

if (dn16384dt(N1)*dt(N1))<n_16384r(N1)
   dn16384_out(N1)=(((beta_b_o*4)+(beta_t_o*(((4*r16384(N1))^3))))*(n_16384r(N1)^2))*dt(N1);
elseif (dn16384dt(N1)*dt(N1-1))>=n_16384r(N1)
    dn16384_out(N1)=0;
end

V1_(N1)=V1_(N1-1)+(dn(N1-1)*V(N1-1))-(dn1_out(N1-1)*(V1_(N1-1)/n_1r(N1-1)));
r1_av(N1)=(V1_(N1)*3/(4*pi*n_1r(N1)))^(1/3);

c1(N1)=c1(N1-1)+((dn(N1-1)*(r(N1-1)^3))-(dn1_out(N1-1)*(r1_av(N1-1)^3)))*(((4*pi)/3)*roSiA/roW)*1000000;
c2(N1)=c2(N1-1)+((dn2dt(N1-1)*dt(N1-1))*(r2(N1-1)^3)*(((4*pi)/3)*roSiA/roW)*1000000);
c4(N1)=c4(N1-1)+((dn4dt(N1-1)*dt(N1-1))*(r4(N1-1)^3)*(((4*pi)/3)*roSiA/roW)*1000000);
c8(N1)=c8(N1-1)+((dn8dt(N1-1)*dt(N1-1))*(r8(N1-1)^3)*(((4*pi)/3)*roSiA/roW)*1000000);
c16(N1)=c16(N1-1)+((dn16dt(N1-1)*dt(N1-1))*(r16(N1-1)^3)*(((4*pi)/3)*roSiA/roW)*1000000);
c32(N1)=c32(N1-1)+((dn32dt(N1-1)*dt(N1-1))*(r32(N1-1)^3)*(((4*pi)/3)*roSiA/roW)*1000000);
c64(N1)=c64(N1-1)+((dn64dt(N1-1)*dt(N1-1))*(r64(N1-1)^3)*(((4*pi)/3)*roSiA/roW)*1000000);
c128(N1)=c128(N1-1)+((dn128dt(N1-1)*dt(N1-1))*(r128(N1-1)^3)*(((4*pi)/3)*roSiA/roW)*1000000);
c256(N1)=c256(N1-1)+((dn256dt(N1-1)*dt(N1-1))*(r256(N1-1)^3)*(((4*pi)/3)*roSiA/roW)*1000000);
c512(N1)=c512(N1-1)+((dn512dt(N1-1)*dt(N1-1))*(r512(N1-1)^3)*(((4*pi)/3)*roSiA/roW)*1000000);
c1024(N1)=c1024(N1-1)+((dn1024dt(N1-1)*dt(N1-1))*(r1024(N1-1)^3)*(((4*pi)/3)*roSiA/roW)*1000000);
c2048(N1)=c2048(N1-1)+((dn2048dt(N1-1)*dt(N1-1))*(r2048(N1-1)^3)*(((4*pi)/3)*roSiA/roW)*1000000);
c4096(N1)=c4096(N1-1)+((dn4096dt(N1-1)*dt(N1-1))*(r4096(N1-1)^3)*(((4*pi)/3)*roSiA/roW)*1000000);
c8192(N1)=c8192(N1-1)+((dn8192dt(N1-1)*dt(N1-1))*(r8192(N1-1)^3)*(((4*pi)/3)*roSiA/roW)*1000000);
c16384(N1)=c16384(N1-1)+((dn16384dt(N1-1)*dt(N1-1))*(r16384(N1-1)^3)*(((4*pi)/3)*roSiA/roW)*1000000);
c512(N1)=c512(N1-1)+((dn512dt(N1-1)*dt(N1-1))*(r512(N1-1)^3)*(((4*pi)/3)*roSiA/roW)*1000000);
c1024(N1)=c1024(N1-1)+((dn1024dt(N1-1)*dt(N1-1))*(r1024(N1-1)^3)*(((4*pi)/3)*roSiA/roW)*1000000);
c2048(N1)=c2048(N1-1)+((dn2048dt(N1-1)*dt(N1-1))*(r2048(N1-1)^3)*(((4*pi)/3)*roSiA/roW)*1000000);
c4096(N1)=c4096(N1-1)+((dn4096dt(N1-1)*dt(N1-1))*(r4096(N1-1)^3)*(((4*pi)/3)*roSiA/roW)*1000000);
c8192(N1)=c8192(N1-1)+((dn8192dt(N1-1)*dt(N1-1))*(r8192(N1-1)^3)*(((4*pi)/3)*roSiA/roW)*1000000);
c16384(N1)=c16384(N1-1)+((dn16384dt(N1-1)*dt(N1-1))*(r16384(N1-1)^3)*(((4*pi)/3)*roSiA/roW)*1000000);
c32768(N1)=c32768(N1-1);
c65536(N1)=c65536(N1-1);
c131072(N1)=c131072(N1-1);
c262144(N1)=c262144(N1-1);
c524288(N1)=c524288(N1-1);
c1048576(N1)=c1048576(N1-1);

end 

%% 
%group calculation into matrixes

%area for deposition
dA_s=zeros(1,N1);
for i=1:N1
    dA_s(i)=pi*D_pipe*(dt(i)*v);             %surface area of pipe segment 
end 

%initial conditions matrixes
for i=1:2
    
    Xn(1,1)=n(1,1);
        
    Xnr(1,1)=n_tV2(1,1);
    
    Xnr(1,2)=Xnr(1,1)+dn(1,1);
    
    Xc(1,1)=c_sio2(1,1);
    
    Xr(1,1)=r(1);
    
    if Xc(1,1)>0
        Xdnout(1,1)=Xkag(1,1)*(((beta_b_o*4)+(beta_t_o*((4*Xr(1,1))^3)))*(Xn(1,1)^2))*dt(1,1);
        Xcdep(1,1)=(deposition_function_wood(N1,Xr(1,1),p,T,Q1))*u_frict*Xc(1,1)*roW*dA_s(1)/Q1;
    else 
        Xdnout(1,1)=0;
        Xcdep(1,1)=0; 
    end 
    
    Xdn(1,1)=dn(1,1)-Xdnout(1,1);
    Xn(1,2)=Xn(1,1)+Xdn(1,1);
    
    if Xc(1,2)>0
        Xdnout(1,2)=Xkag(1,2)*(((beta_b_o*4)+(beta_t_o*((4*Xr(1,2))^3)))*(Xn(1,2)^2))*dt(1,2);
        Xcdep(1,2)=(deposition_function_wood(N1,Xr(1,2),p,T,Q1))*u_frict*Xc(1,2)*roW*dA_s(1,2)/Q1;
    else 
        Xdnout(1,2)=0;
        Xcdep(1,2)=0; 
    end  
    
    XV1_(1)=Xnr(1,1)*((4*pi)/3)*(Xr_av(1)^3);                     %total volume of all particles in group 1 
    XV1_(2)=XV1_(1)+(dn(1)*((4*pi)/3)*(r(1)^3));       %-(dn1_out(1)*4*pi*(r1_av(1)^3)/3);
    Xr_av(1)=r(1);
    Xr_av(2)=(XV1_(2)*3/(4*pi*Xnr(1,2)))^(1/3);
    Xr(1,2)=Xr_av(2);
    
    
    
end 

%radius in each group at time step1
for j=2:N2
    Xr(j,1)=(2^(1/3))*Xr(j-1,1);
end 

%group 1 conditions
for i=2:N1-1
    
    Xr(1,i)=Xr_av(1,i);
    
    if Xc(1,i-1)+((((dn(1,i-1)*(r(1,i-1))^3)-(Xdnout(1,i-1)*(Xr(1,i-1))^3))*((4*pi)/3))*roSiA/roW*1000000)- Xcdep(1,i-1)>0
    Xc(1,i)=Xc(1,i-1)+((((dn(1,i-1)*(r(1,i-1))^3)-(Xdnout(1,i-1)*(Xr(1,i-1))^3))*((4*pi)/3))*roSiA/roW*1000000)- Xcdep(1,i-1);
    else 
         Xc(1,i)=Xc(1,i-1)+((((dn(1,i-1)*(r(1,i-1))^3)-(Xdnout(1,i-1)*(Xr(1,i-1))^3))*((4*pi)/3))*roSiA/roW*1000000);
    end 
    
    Xn(1,i)=Xc(1,i)*roW/((4*pi)*(Xr(1,i)^3)/3*roSiA*1000000);
    %Xkag(1,i)=stability_function(N1,Xr(1,i));
    
    
    if Xc(1,i)>0
        Xdnout(1,i)=Xkag(1,i)*(((beta_b_o*4)+(beta_t_o*((4*Xr(1,i))^3)))*(Xn(1,i)^2))*dt(1,i);
        Xcdep(1,i)=(deposition_function_wood(N1,Xr(1,i),p,T,Q1))*u_frict*Xc(1,i)*roW*dA_s(i)/Q1;
    else 
        Xdnout(1,i)=0;
        Xcdep(1,i)=0;
    end
    
    Xdn(1,i)=dn(1,i)-Xdnout(1,i);

    Xnr(1,i+1)=Xnr(1,i)+(Xdn(1,i));

    if (XV1_(i)+(dn(i)*V(i)))>(Xdnout(1,i)*(XV1_(i)/Xnr(1,i)))
        XV1_(i+1)=V1_(i)+(dn(i)*V(i))-(Xdnout(i)*(XV1_(i)/Xnr(1,i)));                 
    else
        V1_(i+1)=0;
    end

Xr_av(i+1)=(XV1_(i+1)*3/(4*pi*Xnr(1,i+1)))^(1/3); %average radius of one particle
    
end 



%group 2 conditions
for j=2
    
    Xn(2,1)=0;
    
    Xnr(2,1)=0;
    
    Xr(2,1)=(2^(1/3))*Xr(1,1); 
    
    %Xkag(2,1)=stability_function(N1,Xr(2,1));
    
   if  Xc(2,1)>0
    Xdnout(2,1)=Xkag(2,1)*(((beta_b_o*4)+(beta_t_o*((4*Xr(2,1))^3)))*(Xn(2,1)^2))*dt(1,1);
    Xcdep(2,1)=(deposition_function_wood(N1,Xr(2,1),p,T,Q1))*u_frict*Xc(2,1)*roW*dA_s(1)/Q1;
   else 
    Xdnout(2,1)=0;
    Xcdep(2,1)=0;
   end
   
   Xdn(2,1)=0.5*Xdnout(1,1)-Xdnout(2,1);
   
    Xnr(2,2)=Xnr(2,1)+Xdn(2,1);
    
end 

%filling matrixes

for j=2:N2-1
for i=2:N1-1
 
    if Xc(j,i-1)+(Xdn(j,i-1)*(Xr(j,i-1)^3)*(((4*pi)/3)*roSiA/roW)*1000000)-Xcdep(j,i-1)>0
    Xc(j,i)=Xc(j,i-1)+(Xdn(j,i-1)*(Xr(j,i-1)^3)*(((4*pi)/3)*roSiA/roW)*1000000)-Xcdep(j,i-1);
    else 
        Xc(j,i)=Xc(j,i-1)+(Xdn(j,i-1)*(Xr(j,i-1)^3)*(((4*pi)/3)*roSiA/roW)*1000000);
    end 
    
    Xr(j,i)=(2^(1/3))*Xr(j-1,i);
    Xn(j,i)=Xc(j,i)*roW/((4*pi)*(Xr(j,i)^3)/3*roSiA*1000000);
    %Xkag(j,i)=stability_function(N1,Xr(j,i));
    
    if  Xc(j,i)>0
        Xcdep(j,i)=(deposition_function_wood(N1,Xr(j,i),p,T,Q1))*u_frict*Xc(j,i)*roW*dA_s(i)/Q1; 
        Xdnout(j,i)=Xkag(j,i)*(((beta_b_o*4)+(beta_t_o*((4*Xr(j,i)).^3)))*(Xn(j,i).^2))*dt(i); 
    else 
        Xdnout(j,i)=0;
        Xcdep(j,i)=0;
    end
    
    Xdn(j,i)=0.5*Xdnout(j-1,i)-Xdnout(j,i);
            
    Xnr(j,i+1)=Xnr(j,i)+(Xdn(j,i));
     
    
end 
end 

%final condition 

for i=2:N1-1
    
    if Xc(N2,i-1)+(Xdn(N2,i-1)*(Xr(N2,i-1)^3)*(((4*pi)/3)*roSiA/roW)*1000000)-Xcdep(N2,i-1)>0
        
    Xc(N2,i)=Xc(N2,i-1)+(Xdn(N2,i-1)*(Xr(N2,i-1)^3)*(((4*pi)/3)*roSiA/roW)*1000000)-Xcdep(N2,i-1);
    else 
        Xc(N2,i-1)+(Xdn(N2,i-1)*(Xr(N2,i-1)^3)*(((4*pi)/3)*roSiA/roW)*1000000);
    end 
    
    Xr(N2,i)=(2^(1/3))*Xr(N2-1,i);
    Xn(N2,i)=Xc(N2,i)*roW/((4*pi)*(Xr(N2,i)^3)/3*roSiA*1000000); 
    %Xkag(N2,i)=stability_function(N1,Xr(N2,i));
    
    if Xc(N2,i)>0
    Xcdep(N2,i)=(deposition_function_wood(N1,Xr(N2,i),p,T,Q1))*u_frict*Xc(N2,i)*roW*dA_s(i)/Q1;
    else 
    Xcdep(N2,i)=0;
    end 
    
    Xdnout(N2,i)=0;
    
    Xdn(N2,i)=0.5*Xdnout(N2-1,i)-Xdnout(N2,i);
            
    Xnr(N2,i+1)=Xnr(N2,i)+(Xdn(N2,i));
    
end 

%group 1 final condition
for i=N1

    Xr(1,N1)=r1_av(1,N1);

if Xc(1,N1-1)+((((dn(1,N1-1)*(r(1,N1-1))^3)-(Xdnout(1,N1-1)*(Xr(1,N1-1))^3))*((4*pi)/3))*roSiA/roW*1000000)-Xcdep(1,N1-1)>0
    
Xc(1,N1)=Xc(1,N1-1)+((((dn(1,N1-1)*(r(1,N1-1))^3)-(Xdnout(1,N1-1)*(Xr(1,N1-1))^3))*((4*pi)/3))*roSiA/roW*1000000)-Xcdep(1,N1-1);
else 
    Xc(1,N1)=Xc(1,N1-1)+((((dn(1,N1-1)*(r(1,N1-1))^3)-(Xdnout(1,N1-1)*(Xr(1,N1-1))^3))*((4*pi)/3))*roSiA/roW*1000000);
end 
    
Xn(1,N1)=Xc(1,N1)*roW/((4*pi)*(Xr(1,N1)^3)/3*roSiA*1000000);



    if Xc(1,N1)>0
        Xdnout(1,N1)=Xkag(1,N1)*(((beta_b_o*4)+(beta_t_o*((4*Xr(1,N1))^3)))*(Xn(1,N1)^2))*dt(1,N1);
        Xcdep(1,N1)=(deposition_function_wood(N1,Xr(1,N1),p,T,Q1))*u_frict*Xc(1,N1)*roW*dA_s(N1)/Q1;
    else 
        Xdnout(1,N1)=0;
        Xcdep(1,N1)=0;
    end
    
    Xdn(1,N1)=dn(1,N1)-Xdnout(1,N1);

%Xkag(1,N1)=stability_function(N1,Xr(1,N1));

end 

Xr(N2,1)=(2^(1/3))*Xr(N2-1,1);

%Xkag(N1,1)=stability_function(N1,Xr(N2,1));


for i=N1
    for j=2:N2
    
    if Xc(j,N1-1)+(Xdn(j,N1-1)*(Xr(j,N1-1)^3)*(((4*pi)/3)*roSiA/roW)*1000000)-Xcdep(j,N1-1)>0
        
        Xc(j,N1)=Xc(j,N1-1)+(Xdn(j,N1-1)*(Xr(j,N1-1)^3)*(((4*pi)/3)*roSiA/roW)*1000000)-Xcdep(j,N1-1);
    else
        Xc(j,N1)=Xc(j,N1-1)+(Xdn(j,N1-1)*(Xr(j,N1-1)^3)*(((4*pi)/3)*roSiA/roW)*1000000);
    end 
    
    Xr(j,N1)=(2^(1/3))*Xr(j-1,N1);
    Xn(j,N1)=Xc(j,N1)*roW/((4*pi)*(Xr(j,N1)^3)/3*roSiA*1000000);
    %Xkag(j,N1)=stability_function(N1,Xr(j,N1));
     
    if  Xc(j,N1)>0
        Xdnout(j,N1)=(((beta_b_o*4)+(beta_t_o*((4*Xr(j,N1))^3)))*(Xn(j,N1)^2))*dt(N1);
        Xcdep(j,N1)=(deposition_function_wood(N1,Xr(j,N1),p,T,Q1))*u_frict*Xc(j,N1)*roW*dA_s(N1)/Q1;
    else 
        Xdnout(j,N1)=0;
        Xcdep(j,N1)=0;
    end 
    
    Xdn(j,N1)=0.5*Xdnout(j-1,N1)-Xdnout(j,N1);
    
    end     
end


%totals

for j=1:N2
    
    for i=1:N1
    XVp(j,i)=(4*pi)*(Xr(j,i)^3)/3;
    end 
end

for i=1:N1
Xctot=sum(Xc);
Xntot=sum(Xn);
Xntotr=sum(Xnr);
end

for j=2:N2
    for i=2:N1
    Xcper(j,i)=Xc(j,i)/Xctot(1,i);
    Xnper(j,i)=Xn(j,i)/Xntot(1,i);
    end 
end 

    Xcper(1,1)=1;
    Xnper(1,1)=1;
    
    for i=2:N1
    Xcper(1,i)=Xc(1,i)/Xctot(i);
    Xnper(1,i)=Xn(1,i)/Xntot(i);
    end 

for i=1:N1
Xcpertot=sum(Xcper);
end 

for i=1
XVc(1,1)=V1_(1);
XVr(1,1)=V1_(1);
XVrtot(1)=XVr(1,1);
XVctot(1)=XVc(1,1);
end

    XVrtot(1)=0;
    XVctot(1)=0;

for i=2:N1 
    
    for j=1:N2
        
    XVr(j,i)=(4*pi/3)*Xnr(j,i)*(Xr(j,i)^3);  %total volume in each group matrix 
    XVc(j,i)=(4*pi/3)*Xn(j,i)*(Xr(j,i)^3);     %Total volume in each group matrix
    
    end
    
    XVrtot=sum(XVr);
    XVctot=sum(XVc);
end 

for i=1
    Xravr(1)=r1_av(1);
    Xravc(1)=r1_av(1);
end 
    
for i=2:N1
    %Xravr(i)=((XVrtot(i))/Xntotr(i))*(3/(4*pi))^(1/3);  %average radius based on volumes in each group- real number of particles
    %Xravc(i)=((XVctot(i))/Xntot(i))*(3/(4*pi))^(1/3);  %average radius based on volumes in each group- concentration averaged number of particles
    Xravc(i)=((XVctot(i)/Xntot(i))*(3/(4*pi)))^(1/3);  %average radius based on volumes in each group- concentration ave
    Xravr(i)=((XVrtot(i)/Xntotr(i))*(3/(4*pi)))^(1/3);
end


%% Deposition plot

for i=i
% Particle relaxation time

d_min= -8;
d_max= -3;
Nd=500;

d_p=logspace(d_min,d_max,Nd);

r_plot=d_p/2;

l_s = 0.0664 * 10^-6 *(101/p)*(T/293)*((1+(110)/(293))/(1+(110)/(T))); % Crowe

Kn = l_s ./ (d_p); % Knudsen number
Cc = 1 + Kn.*(2.514 + 0.8 .* exp(-0.55./Kn)); % Cunningham slip correction factor
%Cc = 1 + Kn.*(2.34 + 1.05 .* exp(-0.39./Kn)); % Tandberg, uses 0.5*Kn

tau_p= (roSiA * (d_p).^2.*Cc) / (18*visc); % Particle inertia relaxation time
tau_p_plus= tau_p * u_frict^2 / kinvisc; % Dimensionless relaxation time

D_b = (kb*T*Cc)./(3*pi*visc.*d_p); % Brownian diffusion coefficient [m^2/s]

Sc_p = kinvisc ./ D_b; % Particle schmidt number [-]

%% Wood (1981)
Vd_p_wood2=zeros(1,length(tau_p_plus));

for i=1:Nd
Vd_p_wood2(i)=(deposition_function_wood(Nd,r_plot(i),p,T,Q1)); 
end 

%% pp Phutov Phetukov - Coldburn
%new deposition pp function

V_pp_plot3=zeros(1,Nd);

for i=1:Nd
V_pp_plot3(i)=(deposition_function_pp(Nd,r_plot(i),p,T,Q1));     %kvalitetssikret opp mot de andre plottene. 
end

end 

%% %%
%Deposition_testpipe_150bar_q0.23mg/s
%correlation Nusselt- analogy heat and mass transfer 
h_pp_=zeros(1,N1);
h_w_=zeros(1,N1);

for i=1:N1
h_pp_(i)=deposition_function_pp(N1,r_t2(i),p,T,Q1)*u_frict;         %convective mass transfer rate (m/s)
h_w_(i)=deposition_function_wood(N1,r_t2(i),p,T,Q1)*u_frict;         %convective mass transfer rate (m/s)
end 

V_dep_plus_pp=h_pp_./u_frict;
V_dep_plus_w=h_w_./u_frict;

%transport rate of particles to the surface- average value based on average
%radius calculation 

%dependent variables
for i=1
J_pp=zeros(1,N1);
J_w=zeros(1,N1);
time_min_h_J=zeros(1,N1);
dm_sio2_dep_pp=zeros(1,N1);
dm_sio2_dep2_pp=zeros(1,N1);
dm_sio2_dep_w=zeros(1,N1);
dm_sio2_dep2_fa=zeros(1,N1);
m_tot_dep_pp=zeros(1,N1);
m_tot_dep_w=zeros(1,N1);
m_tot_test_a_pp=zeros(1,N1);
m_tot_test_b_pp=zeros(1,N1);
m_tot_test_c_pp=zeros(1,N1);
m_tot_test_d_pp=zeros(1,N1);
m_tot_test_1s_pp=zeros(1,N1);
m_tot_test_0_pp=zeros(1,N1);
m_tot_dep2_pp=zeros(1,N1);
m_tot_dep2_w=zeros(1,N1);
m_tot_test0_pp=zeros(1,N1);
m_tot_test1_pp=zeros(1,N1);
m_tot_test2_pp=zeros(1,N1);
m_tot_test_0_w=zeros(1,N1);
m_tot_test_a_w=zeros(1,N1);
m_tot_test_b_w=zeros(1,N1);
m_tot_test_c_w=zeros(1,N1);
m_tot_test_d_w=zeros(1,N1);
m_tot_test_1s_w=zeros(1,N1);
c_tot_test_1s_w=zeros(1,N1);
m_tot_test0_fa=zeros(1,N1);
m_tot_test1_w=zeros(1,N1);
m_tot_test2_w=zeros(1,N1);
m_tot_test_pp=zeros(1,N1);
m_tot_test_fa=zeros(1,N1);
l1_test=zeros(1,N1);         %span of control section 
l2_test=zeros(1,N1);
l3_test=zeros(1,N1);         %span of control section 
l4_test=zeros(1,N1);
l=zeros(1,N1); 
dc_dep_pp=zeros(1,N1);
dc_dep_w=zeros(1,N1);
c_dep_tot_pp=zeros(1,N1);
c_dep_tot_w=zeros(1,N1);
c_tot_test_1s_pp=zeros(1,N1);
c_tot_test_1s_w=zeros(1,N1);
c_sio2_2_pp=zeros(1,N1);
c_sio2_2_w=zeros(1,N1);

end 


t_0=x_0/v
t_a=x/v
t_b=(x+L1_test)/v;
t_c=x2/v;
t_d=(x2+L1_test)/v;
t_length=L_tot/v;
t_orifice=t_d+((t_length-t_d)/2);


%intitial conditions
for i=1
J_pp(1)=k_ag(1)*h_pp_(1)*c_sio2(1)*roW;                 %transport rate to the surface in mg/m2s including stability
J_w(1)=k_ag(1)*h_w_(1)*c_sio2(1)*roW;                 %transport rate to the surface in mg/m2s including stability

dm_sio2_dep_pp(1)=J_pp(1)*dA_s(1);      %mass deposited on wall in each step in mg/s
dm_sio2_dep_w(1)=J_w(1)*dA_s(1);      %mass deposited on wall in each step in mg/s
dc_dep_pp(1)=dm_sio2_dep_pp(1)/Q1;         %reduction i concentration due to depositionin each step mgsio2/kgw 
dc_dep_w(1)=dm_sio2_dep_w(1)/Q1;         %reduction i concentration due to depositionin each step mgsio2/kgw 
c_sio2_2_pp(1)=c_sio2(1)-dc_dep_pp(1);
c_sio2_2_w(1)=c_sio2(1)-dc_dep_w(1);
dc_dep_w(1)=dm_sio2_dep_w(1)/Q1;         %reduction i concentration due to depositionin each step mgsio2/kgw  
c_sio2_2_w(1)=c_sio2(1)-dc_dep_w(1);
end 

%filling matrixes
for i=2:N1
    
    J_pp(i)=k_ag(i)*h_pp_(i)*c_sio2_2_pp(i-1)*roW;                 %transport rate to the surface in mg/m2s including stability
    J_w(i)=k_ag(i)*h_w_(i)*c_sio2_2_w(i-1)*roW;                 %transport rate to the surface in mg/m2s including stability
   
    dA_s(i)=pi*D_pipe*(dt(i)*v);             %surface area of pipe segment 
    
    dm_sio2_dep_pp(i)=J_pp(i)*dA_s(i);      %mass deposited on wall in each step in mg/s
    dm_sio2_dep_w(i)=J_w(i)*dA_s(i);
    dc_dep_pp(i)=dm_sio2_dep_pp(i)/Q1;         %reduction i concentration due to deposition in each step mgsio2/kgw  
    dc_dep_w(i)=dm_sio2_dep_w(i)/Q1;
    dm_sio2_dep2_pp(i)=J_pp(i)*dA_s(i)*60;      %mass deposited on wall in each step in mg/m
    dm_sio2_dep2_fa(i)=J_w(i)*dA_s(i)*60;      %mass deposited on wall in each step in mg/m
    
    c_dep_tot_pp(i)=c_dep_tot_pp(i-1)+dc_dep_pp(i-1);            %mg/kg -Total depositied material per kg in eaqch step of the test section
    c_dep_tot_w(i)=c_dep_tot_w(i-1)+dc_dep_w(i-1);            %mg/kg -Total depositied material per kg in eaqch step of the test section
    
    %reduction in concentration due to deposition 
    c_sio2_2_pp(i)=c_sio2_2_pp(i-1)+dc_sio2(i-1)-dc_dep_pp(i-1);             %mg/kg -Concentration of solid silica in the bulk flow considering loss due to deposition                                                            
    c_sio2_2_w(i)=c_sio2_2_w(i-1)+dc_sio2(i-1)-dc_dep_w(i-1);
    m_tot_dep2_pp(i)=(c_sio2(i)-c_sio2_2_pp(i))*Q1*60*60;                      %mg/hour
    m_tot_dep2_w(i)=(c_sio2(i)-c_sio2_2_w(i))*Q1*60*60;                      %mg/hour

    m_tot_dep_pp(i)=m_tot_dep_pp(i-1)+(dm_sio2_dep_pp(i)*60*60);    %total mass deposited on wall in the test rig in mg/hour 
    m_tot_dep_w(i)=m_tot_dep_w(i-1)+(dm_sio2_dep_w(i)*60*60);       
    
    %total mass deposited at test 0
        if t(i)<t_0 
            m_tot_test_0_pp(i)=m_tot_test_0_pp(i-1)+(dm_sio2_dep_pp(i)*60*60);
        else 
            m_tot_test_0_pp(i)=m_tot_test_0_pp(i-1);
        end
        if t(i)<t_0 
            m_tot_test_0_w(i)=m_tot_test_0_w(i-1)+(dm_sio2_dep_w(i)*60*60);
        else 
            m_tot_test_0_w(i)=m_tot_test_0_w(i-1);
        end
     %total mass deposited when entering test section 1
        if t(i)<t_a
            m_tot_test_a_pp(i)=m_tot_test_a_pp(i-1)+(dm_sio2_dep_pp(i)*60*60);
        else 
            m_tot_test_a_pp(i)=m_tot_test_a_pp(i-1);
        end
        if t(i)<t_a
            m_tot_test_a_w(i)=m_tot_test_a_w(i-1)+(dm_sio2_dep_w(i)*60*60);
        else 
            m_tot_test_a_w(i)=m_tot_test_a_w(i-1);
        end
        %total mass depositing when exiting test section 1
        if t(i)<t_b
            m_tot_test_b_pp(i)=m_tot_test_b_pp(i-1)+(dm_sio2_dep_pp(i)*60*60);
        else 
            m_tot_test_b_pp(i)=m_tot_test_b_pp(i-1);
        end 
        if t(i)<t_b
            m_tot_test_b_w(i)=m_tot_test_b_w(i-1)+(dm_sio2_dep_w(i)*60*60);
        else 
            m_tot_test_b_w(i)=m_tot_test_b_w(i-1);
        end 
  
   %total mass depositing when entering test section 2
        if t(i)<t_c 
            m_tot_test_c_pp(i)=m_tot_test_c_pp(i-1)+(dm_sio2_dep_pp(i)*60*60);
        else 
            m_tot_test_c_pp(i)=m_tot_test_c_pp(i-1);
        end
        if t(i)<t_c 
            m_tot_test_c_w(i)=m_tot_test_c_w(i-1)+(dm_sio2_dep_w(i)*60*60);
        else 
            m_tot_test_c_w(i)=m_tot_test_c_w(i-1);
        end
        
    %total mass depositing when exiting test section 2
        if t(i)<t_d
            m_tot_test_d_pp(i)=m_tot_test_d_pp(i-1)+(dm_sio2_dep_pp(i)*60*60);
        else 
            m_tot_test_d_pp(i)=m_tot_test_d_pp(i-1);
        end
                if t(i)<t_d
            m_tot_test_d_w(i)=m_tot_test_d_w(i-1)+(dm_sio2_dep_w(i)*60*60);
        else 
            m_tot_test_d_w(i)=m_tot_test_d_w(i-1);
        end
     %total mass deposited after 1 second
        if t(i)<=1
            m_tot_test_1s_pp(i)=m_tot_test_1s_pp(i-1)+(dm_sio2_dep_pp(i)*60*60);
        else 
            m_tot_test_1s_pp(i)=m_tot_test_1s_pp(i-1);
        end
        if t(i)<=1
            m_tot_test_1s_w(i)=m_tot_test_1s_w(i-1)+(dm_sio2_dep_w(i)*60*60);
        else 
            m_tot_test_1s_w(i)=m_tot_test_1s_w(i-1);
        end
        
        %total concentration of deposited mass after 1 second
        if t(i)<=1
            c_tot_test_1s_pp(i)=c_tot_test_1s_pp(i-1)+(dc_dep_pp(i));
        else 
            c_tot_test_1s_pp(i)=c_tot_test_1s_pp(i-1);
        end
        
        if t(i)<=1
            c_tot_test_1s_w(i)=c_tot_test_1s_w(i-1)+(dc_dep_w(i));
        else 
            c_tot_test_1s_w(i)=c_tot_test_1s_w(i-1);
        end
        
    
    %developing a length vector corresponding to time and stable velocity
    
    l(i)=(t(i)*v);                                  %lengt in m correspondning to time with fluid travelling in diameter D_pipe
                                                   %with flow rate of Q
    if t(i)<t_a                                    %L-t illustration
        l1_test(i)=-1;
    else
        l1_test(i)=1;
    end

    if t(i)>t_b
        l2_test(i)=-1;
    else 
        l2_test(i)=1;
    end
    
    if t(i)<t_c                                    %L-t illustration
        l3_test(i)=-1;
    else
        l3_test(i)=1;
    end

    if t(i)>t_d
        l4_test(i)=-1;
    else 
        l4_test(i)=1;
    end
    
time_min_h_J(i)=1./(J_pp(i)*(A_test))/60;       %min/mg

end

% Mass deposited in the test section x<l<x+L per second


for i=1:N1
m_tot_test0_pp(i)=m_tot_test_0_pp(N1);
m_tot_test1_pp(i)=m_tot_test_b_pp(N1)-m_tot_test_a_pp(N1);     %total mass deposited on wall in of the control section 1  in mg/hour
m_tot_test2_pp(i)=m_tot_test_d_pp(N1)-m_tot_test_c_pp(N1);     %total mass deposited on wall in of the control section 2 in mg/hour
m_tot_test0_fa(i)=m_tot_test_0_w(N1);
m_tot_test1_w(i)=m_tot_test_b_w(N1)-m_tot_test_a_w(N1);     %total mass deposited on wall in of the control section 1  in mg/hour
m_tot_test2_w(i)=m_tot_test_d_w(N1)-m_tot_test_c_w(N1);     %total mass deposited on wall in of the control section 2 in mg/hour
end 


%% 
%information at the beginning and at the end of the test sections 



for i=1:N1
if t(i)<t_0
    t_00=t(i);
    i_0=i;
    r_av_0_=r_t2(i);
    n_tot_0_=Xntot(i);
    c_sio2_0=c_sio2(i);
end
    
if t(i)<t_a
    t_aa=t(i);
    i_a=i;
    r_av_a_=r_t2(i);
    r_crit_a=r(i);
    n_tot_a_=Xntot(i);
    c_sio2_a=c_sio2(i);
    c_sio2_2_a=c_sio2_2_pp(i);
    V_dep_plus_pp_a=V_dep_plus_pp(i);
    V_dep_plus_w_a=V_dep_plus_w(i);

    r1_av_a=r1_av(i);
end

if t(i)<t_b
    t_bb=t(i);
    i_b=i;
    r_av_b_=r_t2(i);
    n_tot_b_=Xntot(i);
    c_sio2_b=c_sio2(i);
    c_sio2_2_b=c_sio2_2_pp(i);
    V_dep_plus_pp_b=V_dep_plus_pp(i);
    V_dep_plus_w_b=V_dep_plus_w(i);
end

if t(i)<t_c
    t_cc=t(i);
    i_c=i;
    r_av_c_=r_t2(i);
    r_crit_c=r(i);
    n_tot_c_=Xntot(i);
    c_sio2_c=c_sio2(i);
    c_sio2_2_c=c_sio2_2_pp(i);
    V_dep_plus_pp_c=V_dep_plus_pp(i);
    V_dep_plus_w_c=V_dep_plus_w(i);
    
    r1_av_c=r1_av(i);

    
end
if t(i)<t_d
    t_dd=t(i);
    i_d=i;
    r_av_d_=r_t2(i);
    n_tot_d_=Xntot(i);
    c_sio2_d=c_sio2(i);
    c_sio2_2_d=c_sio2_2_pp(i);
    V_dep_plus_pp_d=V_dep_plus_pp(i);
    V_dep_plus_w_d=V_dep_plus_w(i);
end

if t(i)<=1
    t_1s=t(i);
    i_1=i;
    r_av_1s_=r_t2(i);
    n_tot_1s_=Xntot(i);
    c_sio2_1s=c_sio2(i);
end

if t(i)<=t_orifice
    t_or_=t(i);
    i_or=i;
    r_av_or=r_t2(i);
    n_tot_or=Xntot(i);
    c_sio2_or=c_sio2(i);
    c_sio2_2_pp_or=c_sio2_2_pp(i);

if t(i)<=t_length
    t_length_=t(i);
    i_length=i;
    r_av_length=r_t2(i);
    n_tot_length=Xntot(i);
    c_sio2_length=c_sio2(i);
    c_sio2_2_pp_length=c_sio2_2_pp(i);
end
end
end

%Average values in test section
r_av_ab=(r_av_a_+r_av_b_)/2;
c_sio2_ab=(c_sio2_a+c_sio2_b)/2;
c_sio2_2_ab=(c_sio2_2_a+c_sio2_2_b)/2;
V_dep_plus_pp_ab=(V_dep_plus_pp_a+V_dep_plus_pp_b)/2;
V_dep_ab_=(deposition_function_pp(N1,r_av_a_,p,T,Q1)+deposition_function_pp(N1,r_av_b_,p,T,Q1))/2; 

r_av_cd=(r_av_c_+r_av_d_)/2;
c_sio2_cd=(c_sio2_c+c_sio2_d)/2;
c_sio2_2_cd=(c_sio2_2_c+c_sio2_2_d)/2;
V_dep_plus_pp_cd=(V_dep_plus_pp_c+V_dep_plus_pp_d)/2;
V_dep_cd_=(deposition_function_pp(N1,r_av_c_,p,T,Q1)+deposition_function_pp(N1,r_av_d_,p,T,Q1))/(2); 


for j=1:N2
distra(j)=Xr(j,i_a);
distca(j)=Xc(j,i_a);
distna(j)=Xn(j,i_a);
end 


for j=1:N2
distrc(j)=Xr(j,i_c);
distcc(j)=Xc(j,i_c);
distnc(j)=Xn(j,i_c);
end 

for j=1:N2
distro(j)=Xr(j,i_or);
distco(j)=Xc(j,i_or);
distno(j)=Xn(j,i_or);
end 

for j=1:N2
distr_length(j)=Xr(j,i_length);
distc_length(j)=Xc(j,i_length);

end 


for j=2:N2
    if distca(j)>distca(j-1)
        j_r_a=j;
    end 
end 

r_massmax_a=distra(j_r_a)

for j=2:N2
    if distcc(j)>distcc(j-1)
        j_r_c=j;
    end 
end 

r_massmax_c=distrc(j_r_c)

for j=2:N2
    if distco(j)>distco(j-1)
        j_r_o=j;
    end 
end 

r_massmax_o=distro(j_r_c)


%%  
%test specific calculations 
for i=1

Kn_a_SEM = l_s / (2*r_av_ab_SEM); % Knudsen number
Cc_a_SEM = 1 + Kn_a_SEM*(2.514 + 0.8 * exp(-0.55./Kn_a_SEM)); % Cunningham slip correction factor
%Cc = 1 + Kn.*(2.34 + 1.05 .* exp(-0.39./Kn)); % Tandberg, uses 0.5*Kn

Kn_a_calc = l_s / (2*r_massmax_a); % Knudsen number
Cc_a_calc = 1 + Kn_a_calc*(2.514 + 0.8 * exp(-0.55./Kn_a_calc)); % Cunningham slip correction factor

tau_p_ab_SEM = (roSiA * (2*r_av_ab_SEM)^2*Cc_a_SEM) / (18*visc); % Particle inertia relaxation time
tau_p_plus_ab_SEM = tau_p_ab_SEM * u_frict^2 / kinvisc; % Dimensionless relaxation time
tau_p_a_calc = (roSiA * (2*r_massmax_a)^2*Cc_a_calc) / (18*visc); % Particle inertia relaxation time
tau_p_plus_a_calc = tau_p_a_calc * u_frict^2 / kinvisc; % Dimensionless relaxation time

tau_p_min_ab=(roSiA * (2*rminSEM)^2*Cc_a_SEM) / (18*visc);  %half of radius max min removed x2
tau_p_plus_min_ab = tau_p_min_ab* u_frict^2 / kinvisc; 
tau_p_max_ab=(roSiA * (2*rmaxSEM)^2*Cc_a_SEM) / (18*visc);
tau_p_plus_max_ab = tau_p_max_ab* u_frict^2 / kinvisc; 

Kn_c_SEM = l_s / (2*r_av_cd_SEM); % Knudsen number
Cc_c_SEM = 1 + Kn_c_SEM*(2.514 + 0.8 * exp(-0.55/Kn_c_SEM)); % Cunningham slip correction factor
%Cc = 1 + Kn.*(2.34 + 1.05 .* exp(-0.39./Kn)); % Tandberg, uses 0.5*Kn

Kn_c_calc = l_s / (2*r_massmax_c); % Knudsen number
Cc_c_calc = 1 + Kn_c_calc*(2.514 + 0.8 * exp(-0.55/Kn_c_calc)); % Cunningham slip correction factor
%Cc = 1 + Kn.*(2.34 + 1.05 .* exp(-0.39./Kn)); % Tandberg, uses 0.5*Kn

tau_p_cd_SEM = (roSiA * (2*r_av_cd_SEM)^2*Cc_c_SEM) / (18*visc); % Particle inertia relaxation time
tau_p_plus_cd_SEM = tau_p_cd_SEM * u_frict^2 / kinvisc; % Dimensionless relaxation time
tau_p_c_calc=(roSiA * (2*r_massmax_c)^2*Cc_c_calc) / (18*visc); % Particle inertia relaxation time
tau_p_plus_c_calc = tau_p_c_calc * u_frict^2 / kinvisc; % Dimensionless relaxation time

tau_p_min_cd=(roSiA * (2*rminSEM)^2*Cc_c_SEM) / (18*visc);
tau_p_plus_min_cd = tau_p_min_cd* u_frict^2 / kinvisc; 
tau_p_max_cd=(roSiA * (2*rmaxSEM)^2*Cc_c_SEM) / (18*visc);
tau_p_plus_max_cd = tau_p_max_cd* u_frict^2 / kinvisc;

hpp_ab_=m_ab_dot/(A_test_1*c_sio2_2_ab*roW);   %m/s
hpp_ab_max=m_ab_dot_max/(A_test_1*c_sio2_2_ab*roW);   %m/s
hpp_ab_min=m_ab_dot_min/(A_test_1*c_sio2_ab*roW);   %m/s

%calculating concnetration in test section 2 based on test section 1
for i=i
c_sio2_2_T1=zeros(1,N1);
c_sio2_2_T1(1)=c_sio2_2_pp(1);
J_T1=zeros(1,N1);

for i=2:N1
    J_T1(i)=k_ag(i)*hpp_ab_*c_sio2_2_T1(i-1)*roW;                 %transport rate to the surface in mg/m2s including stability
    
    dm_sio2_dep_T1(i)=J_T1(i)*dA_s(i);      %mass deposited on wall in each step in mg/s
    dc_dep_T1(i)=dm_sio2_dep_T1(i)/Q1;         %reduction i concentration due to deposition in each step mgsio2/kgw  

    c_sio2_2_T1(i)=c_sio2_2_T1(i-1)+dc_sio2(i-1)-dc_dep_T1(i-1);

if t(i)<t_a
    c_sio2_2_a_T1=c_sio2_2_T1(i); 
end

if t(i)<t_b
    c_sio2_2_b_T1=c_sio2_2_T1(i);
end
    
if t(i)<t_c
    c_sio2_2_c_T1=c_sio2_2_T1(i); 
end

if t(i)<t_d
    c_sio2_2_d_T1=c_sio2_2_T1(i);
end
end 

c_sio2_2_abT1=(c_sio2_2_a_T1+c_sio2_2_b_T1)/2
c_sio2_2_cdT1=(c_sio2_2_c_T1+c_sio2_2_d_T1)/2
end 

hpp_ab_=m_ab_dot/(A_test_1*c_sio2_2_abT1*roW);   %m/s
hpp_ab_max=m_ab_dot_max/(A_test_1*c_sio2_2_ab*roW);   %m/s
hpp_ab_min=m_ab_dot_min/(A_test_1*c_sio2_2_abT1*roW);   %m/s

hpp_cd_=m_cd_dot/(A_test_2*c_sio2_2_cdT1*roW);   %m/s
hpp_cd_max=m_cd_dot_max/(A_test_1*c_sio2_2_cd*roW);   %m/s
hpp_cd_min=m_cd_dot_min/(A_test_1*c_sio2_cd*roW);   %m/s

Vd_plus_ab_test=hpp_ab_/u_frict
Vd_ab_max=hpp_ab_max/u_frict;
Vd_ab_min=hpp_ab_min/u_frict;

Vd_plus_cd_test=hpp_cd_/u_frict
Vd_cd_max=hpp_cd_max/u_frict;
Vd_cd_min=hpp_cd_min/u_frict;

Vd_calc_a=(deposition_function_wood(N1,r_massmax_a,p,T,Q1));
Vd_calc_c=(deposition_function_wood(N1,r_massmax_c,p,T,Q1));

%r_test=[r_av_ab, r_av_cd];
tau_test=[tau_p_plus_ab_SEM, tau_p_plus_cd_SEM];
tau_test_ab_maxmin=[tau_p_plus_ab_SEM, tau_p_plus_ab_SEM];
tau_test_cd_maxmin=[tau_p_plus_cd_SEM, tau_p_plus_cd_SEM];
Vd_tau_ab_maxmin=[Vd_plus_ab_test,Vd_plus_ab_test];
Vd_tau_cd_maxmin=[Vd_plus_cd_test,Vd_plus_cd_test];
Vd_test=[Vd_plus_ab_test, Vd_plus_cd_test];
Vd_test_ab_maxmin=[Vd_ab_max, Vd_ab_min];
Vd_test_cd_maxmin=[Vd_cd_max, Vd_cd_min];
tau_uncert_ab=[tau_p_plus_min_ab, tau_p_plus_max_ab];
tau_uncert_cd=[tau_p_plus_min_cd, tau_p_plus_max_cd];
end 
%% 

%printed values 

writematrix(distra);
writematrix(distca);
writematrix(distna);

%i_a
%r_av_a_
%r_crit_a
n_tot_a_
c_sio2_a
%c_sio2_2_a
r_av_ab
c_sio2_ab
c_sio2_2_ab

%i_c
r_av_c_
r_crit_c
n_tot_c_
c_sio2_c
%c_sio2_2_c
r_av_cd
c_sio2_cd
c_sio2_2_cd

%i_0
%r_av_0_
%n_tot_0_
%c_sio2_0

%t_1s
%r_av_1s_
%n_tot_1s_
%c_sio2_1s

XVp(N2,i_a)

Vd_plus_ab_test
Vd_plus_cd_test
V_dep_plus_pp_ab
V_dep_plus_pp_cd

m_tot_0_pp=m_tot_test_0_pp(N1-2);
m_tot_testab_pp=m_tot_test1_pp(N1-2)
m_tot_testcd_pp=m_tot_test2_pp(N1-2)
m_tot_1s_pp=m_tot_test_1s_pp(N1-2);
c_tot_1s_pp=c_tot_test_1s_pp(N1-2);

m_tot_0_w=m_tot_test_0_w(N1-2);
m_tot_testab_w=m_tot_test1_w(N1-2);
m_tot_testcd_w=m_tot_test2_w(N1-2);
m_tot_1s_w=m_tot_test_1s_w(N1-2);
c_tot_1s_w=c_tot_test_1s_w(N1-2);

%% 

%Figures

fontProps.FontName = 'Calibri';
fontProps.FontSize = 14;        %default units: points units (1 p.u.=1/72 inch)-
fontProps.FontWeight = 'bold';

figProps.Color = [1 1 1]; %Background figure color set to white.

plotpaa_c=1;
plotpaa_corg=0;
plotpaa_n=0;
plotpaa_ntj=0;
plotpaa_r=0;
plotpaa_rtj=0;
plotpaa_Vp=0;
plotpaa_Vtot=0;
plotpaa_cgrouptj=1;
plotpaa_ngrouptj=0;
plotpaa_rgroups=1;
plotpaa_ndist=0;
plotpaa_dn=0; 
plotpaa_norg=0;
plotpaa_Jpp=0;
plotpaa_mdep=0;
plotpaa_dista=0;
plotpaa_Vp=0;
plotpaa_cdep=0;
plotpaa_mtestsect=1;
plotpaa_Xcaa=1;
plotpaa_Xr=1;
plotpaa_Xcadist=1;
plotpaa_Xcadist_tj=1;
plotpaa_Xcaa_tj=1;
plotpaa_Xndist=1;
plotpaa_Xndisttj=1;
plotpaa_Xcper=1;
plotpaa_Xcpertj=1;
plotpaa_Vd=1;
plotpaa_Vd2=1;
plotpaa_Vd3=1;
plotpaa_Vd4=1;

N=8;
C = linspecer(N);


%% 
%concentration profile
for plot_c=plotpaa_c
    if plot_c==1
        
Figure_c = figure(1); %Name of figure

%Use of set statement to the define properties for the figure.
set(Figure_c, figProps)
%Use a set statement to define properties for fonts.
set(axes, fontProps)
%Set limits in the "x" coordinate, place boarder around plot, and use
%gridlines.
xlim([0 1e5])
ylim([-1 300]);


ax = gca;
ax.XAxis.Scale = 'log';
xticks([10^-30 10^-20 10^-10 10^00 10^10 10^20 10^30 10^40])
xticklabels({'10^-^3^0','10^-^2^0','10^-^1^0','10^0','10^1^0','10^2^0','10^3^0','10^4^0'})

%Plot the function

hold on
box on
grid on

plot(t, c, 'Color', 'r', 'LineWidth', 7);               %concentration of dissolved particles in the steam 
plot(t, c_sio2, 'Color', 'b', 'LineWidth', 7);          %concentration of solid particles in the steam not considering deposition
%plot(t, c_tot, 'Color', 'g', 'LineWidth', 5);           %total concentration based on concentration averaged number of particles.considering deposition through nXc
plot(t, c_dep_tot_pp, 'Color', 'k', 'LineWidth', 4);    %total concentration based on concentration averaged number of particles.considering deposition through nXc
%plot(t, c_dep_tot_fa, 'Color', 'k', 'LineWidth', 3);    %total concentration based on concentration averaged number of particles.considering deposition through nXc
plot(t, c_sio2_2_pp, 'Color', 'k', 'LineWidth', 4);    %total concentration based on concentration averaged number of particles.considering deposition through nXc
plot(t, Xctot, 'Color', 'g', 'LineWidth', 1);           %total concentration based on concentration averaged number of particles.considering deposition through nXc

for j = 1:N2
 plot(t,Xc(j,:), 'Color', 'm', 'LineWidth', 1)
end
         
            
Title_c=title('Decrease in concentration of silicic acid as a function of time');
set(Title_c, fontProps)
XL=xlabel('time (s)'); 
set(XL, fontProps)
YL=ylabel('Concentration (mg/kg)'); 
set(YL, fontProps)
legend('c(t)', 'csio2(t)','cdeppp','cSio22','Xctot', 'Group distribution')
set(legend, fontProps)


    end 
end

%% number of particles total and sgglomerated
for plot_n=plotpaa_n
    if plot_n==1

    Figure_n = figure(3); %Name of figure

    %Use of set statement to the define properties for the figure.
    set(Figure_n, figProps)
    %Use a set statement to define properties for fonts.
    set(axes, fontProps)
    %Set limits in the "x" coordinate, place boarder around plot, and use
    %gridlines.
    xlim([0 1e5])
    ylim([1 1e23]);

    ax = gca;
    ax.YAxis.Scale = 'log';
    yticks([ 10^03 10^04 10^05 10^06 10^07 10^08 10^09 10^10 10^11 10^12 10^13 10^14 10^15 ...
        10^16 10^17 10^18 10^19 10^20 10^21 10^22 10^23 10^24 10^25 10^26 10^27])
    yticklabels({'10^3','10^4','10^5','10^6','10^7','10^8','10^9','10^1^0','10^1^1','10^1^2','10^1^3','10^1^4',...
        '10^1^5','10^1^6','10^1^7','10^1^8','10^1^9','10^2^0','10^2^1','10^2^2','10^2^3','10^2^4','10^2^5','10^2^6','10^2^7'})

    ax = gca;
    ax.XAxis.Scale = 'log';
    xticks([10^-30 10^-20 10^-10 10^00 10^10 10^20 10^30 10^40])
    xticklabels({'10^-^3^0','10^-^2^0','10^-^1^0','10^0','10^1^0','10^2^0','10^3^0','10^4^0'})

    %Plot the function
    %Plot the function

    hold on
    box on
    grid on

    plot(t, n, 'Color', 'r', 'LineWidth', 7, 'Marker', 'o', ...
        'MarkerEdgeColor', 'r', ...
        'MarkerFaceColor', 'none');
    plot(t, n_tV2, 'Color', 'b', 'LineWidth', 7, 'Marker', 'o', ...
        'MarkerEdgeColor', 'b', ...
        'MarkerFaceColor', 'none');
    plot(t, Xntot, 'Color', 'y', 'LineWidth', 4, 'Marker', 'o', ...
        'MarkerEdgeColor', 'y', ...
        'MarkerFaceColor', 'none');
    plot(t, Xntotr, 'Color', 'k', 'LineWidth', 2, 'Marker', 'o', ...
        'MarkerEdgeColor', 'k', ...
        'MarkerFaceColor', 'none');
    
    for j = 1:N2
    plot(t,Xn(j,:), 'Color', 'm', 'LineWidth', 1)
    end

    Title_n=title('Decrease in concentration of silicic acid as a function of time');
    set(Title_n, fontProps)
    XL=xlabel('time (s)');
    set(XL, fontProps)
    YL=ylabel('Number of particles');
    set(YL, fontProps)
    legend('n','ntV2','Xntot','Xntotr');
    set(legend, fontProps)

    end
end 

%% number of particles plot linpece
for plot_ntj=plotpaa_ntj
    if plot_ntj==1

        Figure_n_tj=figure(2);

N = 3;
C = linspecer(N);
loglog(t,n,'color', C(1,:),'marker','o','LineStyle',':','LineWidth',4); hold on
loglog(t,n_tV2,'color', C(2,:),'marker','square','LineStyle',':','LineWidth',2);
grid on 
set(gca,'fontsize', 18);
p = p*10;
xlabel('time (s)')
ylabel('Number of particles')
title('Particle number development', 'FontSize',18);


legend ('n','ntV2');

    end
end

%% Radius plot 
for plot_r=plotpaa_r
    if plot_r==1

Figure_r = figure(4); %Name of figure

%Use of set statement to the define properties for the figure.
set(Figure_r, figProps)
%Use a set statement to define properties for fonts.
set(axes, fontProps)
%Set limits in the "x" coordinate, place boarder around plot, and use
%gridlines.
xlim([0 1e5])
ylim([1e-10 5e-7]);

ax = gca;
ax.YAxis.Scale = 'log';
yticks([ 10^-10 10^-09 10^-08 10^-07 10^-06 10^-05 10^-04 10^-03 ])
yticklabels({'10^-^1^0','10^-^9','10^-^8','10^-^7','10^-^6','10^-^5','10^-^4','10^-^3'}) 

ax = gca;
ax.XAxis.Scale = 'log';
xticks([10^-30 10^-20 10^-10 10^00])
xticklabels({'10^-^3^0','10^-^2^0','10^-^1^0','10^0'})

%Plot the function

hold on
box on
grid on
            
plot(t, r, 'Color', 'b', 'LineWidth', 7, 'Marker', 'o', ...
                'MarkerEdgeColor', 'b', ...
                'MarkerFaceColor', 'none');
plot(t, r_t2, 'Color', 'r', 'LineWidth', 7, 'Marker', 'o', ...
                'MarkerEdgeColor', 'r', ...
                'MarkerFaceColor', 'none');
plot(t, r1_av, 'Color', 'g', 'LineWidth', 5, 'Marker', 'o', ...
                'MarkerEdgeColor', 'g', ...
                'MarkerFaceColor', 'none');
%plot(t, r_av_c, 'Color', 'm', 'LineWidth',3);
%plot(t, r_av_r, 'Color', 'y', 'LineWidth', 3);
plot(t, Xravc, 'Color', 'k', 'LineWidth', 2);
%plot(t, Xravr, 'Color', 'c', 'LineWidth', 2);
            
%set(YL, fontProps)
legend('Critical radius of particles generated','Average particle radius taking into account agglomeration','Average particle size in group 1','Average particle radius in all groups considered')
set(legend, fontProps)

Title_r=title('Development of particle radius');
set(Title_r, fontProps)
XL=xlabel('time (s)'); 
set(XL, fontProps)
YL=ylabel('particle radius (m)'); 
    end
end 

%% Radius plot_tj
for plot_rtj=plotpaa_rtj
    if plot_rtj==1

Figure_rtp=figure(5);

N = 4;
C = linspecer(N);
loglog(t,r,'color', C(1,:),'marker','o','LineStyle',':','LineWidth',6); hold on
loglog(t,r_t2,'color', C(2,:),'marker','square','LineStyle',':','LineWidth',4);
loglog(t,r1_av,'color', C(3,:),'marker','square','LineStyle',':','LineWidth',2);
loglog(t,r_av_c,'color', C(4,:),'marker','square','LineStyle',':','LineWidth',1);
grid on 
set(gca,'fontsize', 18);
p = p*10;
xlabel('time (s)')
ylabel('Number of particles')
title('Particle number development', 'FontSize',18);


legend ('r','rt2', 'r1av','rc');

    end
end

%% Volumes of particles
for plot_Vp=plotpaa_Vp
    if plot_Vp==1
    
Figure_Vp=figure(6);

N = 4;
C = linspecer(N);
loglog(t,Vp1,'color', C(1,:),'marker','o','LineStyle',':','LineWidth',6); hold on
loglog(t,Vp16,'color', C(2,:),'marker','square','LineStyle',':','LineWidth',4);
loglog(t,Vp16384,'color', C(3,:),'marker','square','LineStyle',':','LineWidth',2);
loglog(t,Vp1048576,'color', C(4,:),'marker','square','LineStyle',':','LineWidth',1);

grid on 
set(gca,'fontsize', 18);
p = p*10;
xlabel('time (s)')
ylabel('Volume')
title('Volume of particles in different groups', 'FontSize',18);

legend('Vp1','Vp16','Vp16384','Vpx24')


    end
end

%% Average total volumes
for plot_Vtot=plotpaa_Vtot
    if plot_Vtot==1
     Figure_Vtot=figure(5);

N = 1;
C = linspecer(N);
loglog(t,V1_,'color', C(1,:),'marker','o','LineStyle',':','LineWidth',6); hold on
%loglog(t,V_av1,'color', C(2,:),'marker','square','LineStyle',':','LineWidth',4);
%loglog(t,V_av_c,'color', C(3,:),'marker','square','LineStyle',':','LineWidth',2);
%loglog(t,V_av_r,'color', C(4,:),'marker','square','LineStyle',':','LineWidth',1);
%loglog(t,V_p2,'color', C(4,:),'marker','square','LineStyle',':','LineWidth',1);
    
grid on 
set(gca,'fontsize', 18);
p = p*10;
xlabel('time (s)')
ylabel('Volume')
title('Volume comparison', 'FontSize',18);

legend ('V1','V_av1');  
    end
end 

%% 
%concentration profile
for plot_corg=plotpaa_corg
    if plot_corg==1 
        
Figure_c = figure(9); %Name of figure

%Use of set statement to the define properties for the figure.
set(Figure_c, figProps)
%Use a set statement to define properties for fonts.
set(axes, fontProps)
%Set limits in the "x" coordinate, place boarder around plot, and use
%gridlines.
xlim([0 1e5])
ylim([-1 300]);


ax = gca;
ax.XAxis.Scale = 'log';
xticks([10^-30 10^-20 10^-10 10^00 10^10 10^20 10^30 10^40])
xticklabels({'10^-^3^0','10^-^2^0','10^-^1^0','10^0','10^1^0','10^2^0','10^3^0','10^4^0'})

%Plot the function

hold on
box on
grid on

plot(t, c, 'Color', 'r', 'LineWidth', 7, 'Marker', 'o', ...
                'MarkerEdgeColor', 'r', ...
                'MarkerFaceColor', 'none');
plot(t, c_sio2, 'Color', 'b', 'LineWidth', 7, 'Marker', 'o', ...
                'MarkerEdgeColor', 'b', ...
                'MarkerFaceColor', 'none');
plot(t, c_tot, 'Color', 'g', 'LineWidth', 7, ...
                'MarkerEdgeColor', 'g', ...
                'MarkerFaceColor', 'none');
plot(t, c1, 'Color', 'm', 'LineWidth', 7, ...
                'MarkerEdgeColor', 'm', ...
                'MarkerFaceColor', 'none');
plot(t, c2, 'Color', 'm', 'LineWidth', 5, ...
                'MarkerEdgeColor', 'm', ...
                'MarkerFaceColor', 'none');
plot(t, c8, 'Color', 'm', 'LineWidth', 5, ...
                'MarkerEdgeColor', 'm', ...
                'MarkerFaceColor', 'none');
plot(t, c32, 'Color', 'm', 'LineWidth', 5, ...
                'MarkerEdgeColor', 'm', ...
                'MarkerFaceColor', 'none');
plot(t, c128, 'Color', 'm', 'LineWidth', 5, ...
                'MarkerEdgeColor', 'm', ...
                'MarkerFaceColor', 'none');
plot(t, c256, 'Color', 'm', 'LineWidth', 3, ...
                'MarkerEdgeColor', 'm', ...
                'MarkerFaceColor', 'none');
plot(t, c512, 'Color', 'm', 'LineWidth', 3, ...
                'MarkerEdgeColor', 'm', ...
                'MarkerFaceColor', 'none');
plot(t, c1024, 'Color', 'c', 'LineWidth', 3, ...
                'MarkerEdgeColor', 'c', ...
                'MarkerFaceColor', 'none');
plot(t, c2048, 'Color', 'm', 'LineWidth', 3, ...
                'MarkerEdgeColor', 'm', ...
                'MarkerFaceColor', 'none');
plot(t, c4096, 'Color', 'm', 'LineWidth', 1, ...
                'MarkerEdgeColor', 'm', ...
                'MarkerFaceColor', 'none');
plot(t, c8192, 'Color', 'm', 'LineWidth', 1, ...
                'MarkerEdgeColor', 'm', ...
                'MarkerFaceColor', 'none');
plot(t, c16384, 'Color', 'c', 'LineWidth', 1);

plot(t, c32768, 'Color', 'm', 'LineWidth', 3, ...
                'MarkerEdgeColor', 'm', ...
                'MarkerFaceColor', 'none');
plot(t, c65536, 'Color', 'c', 'LineWidth', 3, ...
                'MarkerEdgeColor', 'c', ...
                'MarkerFaceColor', 'none');
plot(t, c131072, 'Color', 'm', 'LineWidth', 3, ...
                'MarkerEdgeColor', 'm', ...
                'MarkerFaceColor', 'none');
plot(t, c262144, 'Color', 'm', 'LineWidth', 1, ...
                'MarkerEdgeColor', 'm', ...
                'MarkerFaceColor', 'none');
plot(t, c524288, 'Color', 'm', 'LineWidth', 1, ...
                'MarkerEdgeColor', 'm', ...
                'MarkerFaceColor', 'none');
plot(t, c1048576, 'Color', 'c', 'LineWidth', 1);

plot(t, c_sio2_2_pp, 'Color', 'g', 'LineWidth', 1, ...
                'MarkerEdgeColor', 'g', ...
                'MarkerFaceColor', 'none');
plot(t, c_sio2_2_w, 'Color', 'b', 'LineWidth', 1, ...
                'MarkerEdgeColor', 'b', ...
                'MarkerFaceColor', 'none');
plot(t, c_dep_tot_pp, 'Color', 'k', 'LineWidth', 2, ...
                'MarkerEdgeColor', 'k', ...
                'MarkerFaceColor', 'none');
plot(t, c_dep_tot_w, 'Color', 'k', 'LineWidth', 2, ...
                'MarkerEdgeColor', 'k', ...
                'MarkerFaceColor', 'none');
            
Title_c=title('Decrease in concentration of silicic acid as a function of time');
set(Title_c, fontProps)
XL=xlabel('time (s)'); 
set(XL, fontProps)
YL=ylabel('Concentration (mg/kg)'); 
set(YL, fontProps)
legend('c(t)', 'c_sio2(t)','c_t_o_t', 'c1', 'c2', 'c8', 'c32', 'c128', 'c256', 'c512', 'c1024', 'c2048', 'c4096',...
        'c8192', 'c16384','c32768','c65536','c131072','c262144','c524288','c1048576', 'cdeppp', 'cdepfa', 'cdeptot') %, 'c_t_o_t_2'
set(legend, fontProps)
    end 
end

%% 
%Development of average radius
for plot_rgroups=plotpaa_rgroups 
    if plot_rgroups==1
    
Figure_rgroups = figure(10); %Name of figure

%Use of set statement to the define properties for the figure.
set(Figure_rgroups, figProps)
%Use a set statement to define properties for fonts.
set(axes, fontProps)
%Set limits in the "x" coordinate, place boarder around plot, and use
%gridlines.
xlim([0 1e5])
ylim([1e-10 5e-7]);

ax = gca;
ax.YAxis.Scale = 'log';
yticks([ 10^-10 10^-09 10^-08 10^-07 10^-06 10^-05 10^-04 10^-03 ])
yticklabels({'10^-^1^0','10^-^9','10^-^8','10^-^7','10^-^6','10^-^5','10^-^4','10^-^3'}) 

ax = gca;
ax.XAxis.Scale = 'log';
xticks([10^-30 10^-20 10^-10 10^00])
xticklabels({'10^-^3^0','10^-^2^0','10^-^1^0','10^0'})

%Plot the function

hold on
box on
grid on

plot(t, r, 'Color', 'r', 'LineWidth', 2, 'Marker', 'o', ...
                'MarkerEdgeColor', 'r', ...
                'MarkerFaceColor', 'none');


plot(t, r_t2, 'Color', 'y', 'LineWidth', 2, ...
                'MarkerEdgeColor', 'y', ...
                'MarkerFaceColor', 'none');


%plot(t, r1, 'Color', 'c', 'LineWidth', 2, ...
 %               'MarkerEdgeColor', 'c', ...
  %              'MarkerFaceColor', 'none');

plot(t, r1_av, 'Color', 'b', 'LineWidth', 6, ...
                'MarkerEdgeColor', 'b', ...
                'MarkerFaceColor', 'none');

%plot(t, r128, 'Color', 'k', 'LineWidth', 2, ...
 %               'MarkerEdgeColor', 'k', ...
  %              'MarkerFaceColor', 'none');
   
plot(t, r1048576, 'Color', 'c', 'LineWidth', 2, ...
                'MarkerEdgeColor', 'c', ...
                'MarkerFaceColor', 'none');          
            
plot(t, r_av_c, 'Color', 'g', 'LineWidth', 2, ...
                'MarkerEdgeColor', 'g', ...
                'MarkerFaceColor', 'none');

%plot(t, r_av_r, 'Color', 'm', 'LineWidth', 2, ...
 %               'MarkerEdgeColor', 'm', ...
  %              'MarkerFaceColor', 'none');
  
%plot(t, r1024, 'Color', 'b', 'LineWidth', 2, ...
 %               'MarkerEdgeColor', 'b', ...
  %              'MarkerFaceColor', 'none');
           
%set(YL, fontProps)
legend('rcrit', 'raggl', 'r1', 'r1048576', ...
    'ravc') 
set(legend, fontProps)
     
Title_r_av=title('Change in critical radius due to change in concentration and total average radius of particles in the solution due to agglomeration');
set(Title_r_av, fontProps)
XL=xlabel('time (s)');
set(XL, fontProps)
YL=ylabel('Radius (m)'); 

    end 
end 

%% 
%change in number concnetration 
for plot_ndist=plotpaa_ndist 
    if plot_ndist==1
        
Figure_ndist = figure(11); %Name of figure

%Use of set statement to the define properties for the figure.
set(Figure_ndist, figProps)
%Use a set statement to define properties for fonts.
set(axes, fontProps)
%Set limits in the "x" coordinate, place boarder around plot, and use
%gridlines.
xlim([0 1e5])
ylim([1 1e22]);

ax = gca;
ax.YAxis.Scale = 'log';
yticks([ 10^03 10^04 10^05 10^06 10^07 10^08 10^09 10^10 10^11 10^12 10^13 10^14 10^15 ...
    10^16 10^17 10^18 10^19 10^20 10^21 10^22 10^23 10^24 10^25 10^26 10^27])
yticklabels({'10^3','10^4','10^5','10^6','10^7','10^8','10^9','10^1^0','10^1^1','10^1^2','10^1^3','10^1^4',...
    '10^1^5','10^1^6','10^1^7','10^1^8','10^1^9','10^2^0','10^2^1','10^2^2','10^2^3','10^2^4','10^2^5','10^2^6','10^2^7'})

ax = gca;
ax.XAxis.Scale = 'log';
xticks([10^-30 10^-20 10^-10 10^00 10^10 10^20 10^30 10^40])
xticklabels({'10^-^3^0','10^-^2^0','10^-^1^0','10^0','10^1^0','10^2^0','10^3^0','10^4^0'})

%Plot the function

hold on
box on
grid on

plot(t, n_1r, 'Color', 'r', 'LineWidth', 2, 'Marker', 'o', ...
                'MarkerEdgeColor', 'r', ...
                'MarkerFaceColor', 'none');


plot(t, n_2r, 'Color', 'b', 'LineWidth', 2, 'Marker', 'o', ...
                'MarkerEdgeColor', 'b', ...
                'MarkerFaceColor', 'none');
            
plot(t, n_4r, 'Color', 'y', 'LineWidth', 2, 'Marker', 'o', ...
                'MarkerEdgeColor', 'y', ...
                'MarkerFaceColor', 'none');
            
plot(t, n_8r, 'Color', 'g', 'LineWidth', 2, 'Marker', 'o', ...
                'MarkerEdgeColor', 'g', ...
                'MarkerFaceColor', 'none');

plot(t, n_16r, 'Color', 'k', 'LineWidth', 2, 'Marker', 'o', ...
                'MarkerEdgeColor', 'k', ...
                'MarkerFaceColor', 'none');

plot(t, n_32r, 'Color', 'g', 'LineWidth', 2, 'Marker', 'o', ...
                'MarkerEdgeColor', 'g', ...
                'MarkerFaceColor', 'none');
            
plot(t, n_64r, 'Color', 'g', 'LineWidth', 2, 'Marker', 'o', ...
                'MarkerEdgeColor', 'g', ...
                'MarkerFaceColor', 'none');
            
plot(t, n_128r, 'Color', 'y', 'LineWidth', 2, 'Marker', 'o', ...
                'MarkerEdgeColor', 'y', ...
                'MarkerFaceColor', 'none');
            
plot(t, n_256r, 'Color', 'k', 'LineWidth', 2, 'Marker', 'o', ...
                'MarkerEdgeColor', 'k', ...
                'MarkerFaceColor', 'none');

plot(t, n_512r, 'Color', 'g', 'LineWidth', 2, 'Marker', 'o', ...
                'MarkerEdgeColor', 'g', ...
                'MarkerFaceColor', 'none');
            
plot(t, n_1024r, 'Color', 'g', 'LineWidth', 2, 'Marker', 'o', ...
                'MarkerEdgeColor', 'g', ...
                'MarkerFaceColor', 'none');
            
plot(t, n_2048r, 'Color', 'y', 'LineWidth', 2, 'Marker', 'o', ...
                'MarkerEdgeColor', 'y', ...
                'MarkerFaceColor', 'none');
            
plot(t, n_4096r, 'Color', 'y', 'LineWidth', 2, 'Marker', 'o', ...
                'MarkerEdgeColor', 'y', ...
                'MarkerFaceColor', 'none');
            
plot(t, n_8192r, 'Color', 'y', 'LineWidth', 2, 'Marker', 'o', ...
                'MarkerEdgeColor', 'y', ...
                'MarkerFaceColor', 'none');

plot(t, n_16384r, 'Color', 'y', 'LineWidth', 2, 'Marker', 'o', ...
                'MarkerEdgeColor', 'y', ...
                'MarkerFaceColor', 'none'); 
plot(t, n_32768r, 'Color', 'm', 'LineWidth', 3, ...
                'MarkerEdgeColor', 'm', ...
                'MarkerFaceColor', 'none');
plot(t, n_65536r, 'Color', 'c', 'LineWidth', 3, ...
                'MarkerEdgeColor', 'c', ...
                'MarkerFaceColor', 'none');
plot(t, n_131072r, 'Color', 'm', 'LineWidth', 3, ...
                'MarkerEdgeColor', 'm', ...
                'MarkerFaceColor', 'none');
plot(t, n_262144r, 'Color', 'm', 'LineWidth', 1, ...
                'MarkerEdgeColor', 'm', ...
                'MarkerFaceColor', 'none');
plot(t, n_524288r, 'Color', 'm', 'LineWidth', 1, ...
                'MarkerEdgeColor', 'm', ...
                'MarkerFaceColor', 'none');
plot(t, n_1048576r, 'Color', 'c', 'LineWidth', 1);
            
           
plot(t, n_tV2, 'Color', 'k', 'LineWidth', 2, ...
                'MarkerEdgeColor', 'k', ...
                'MarkerFaceColor', 'none');

plot(t, n_tot_r, 'Color', 'c', 'LineWidth', 2, ...
                'MarkerEdgeColor', 'c', ...
                'MarkerFaceColor', 'none');
 
            
%set(YL, fontProps)
legend('n_g1', 'n_g2', 'n_g4', 'n_g8', 'n_r16', 'n_r32', 'n_r64', 'n_r128', 'n_r256', 'n_r512', 'n_r1024',...
    'n_r2048', 'n_r4096','n_r8192', 'n_r8192', 'n_r16384','n_r32768','n_r65536','n_r131072','n_r262144','n_r524288',...
    'n_r1048576', 'n_a_g_g', 'n_t_o_t') %, 
set(legend, fontProps)
     
Title_n_dist=title('Particle number size distribution development');
set(Title_n_dist, fontProps)
XL=xlabel('time (s)'); 
set(XL, fontProps)
YL=ylabel('Number distribution (m)'); 

    end 
end

%% 
%change in deposition rate 

for plot_dn=plotpaa_dn
    if plot_dn==1
        
Figure_dn = figure(12); %Name of figure

%Use of set statement to the define properties for the figure.
set(Figure_dn, figProps)
%Use a set statement to define properties for fonts.
set(axes, fontProps)
%Set limits in the "x" coordinate, place boarder around plot, and use
%gridlines.
%xlim([0 1e5])
ylim([1e-10 1e35]);

ax = gca;
ax.YAxis.Scale = 'log';
yticks([ 10^-30 10^-20 10^-10 10^00 10^10 10^20 10^30 ])
yticklabels({'10^-^3^0','10^-^2^0','10^-^1^0','10^0','10^1^0','10^2^0','10^3^0'})  

ax = gca;
ax.XAxis.Scale = 'log';
xticks([10^-30 10^-20 10^-10 10^00 10^10 10^20 10^30 10^40])
xticklabels({'10^-^3^0','10^-^2^0','10^-^1^0','10^0','10^1^0','10^2^0','10^3^0','10^4^0'})

%Plot the function

hold on
box on
grid on

plot(t, dn, 'Color', 'k', 'LineWidth', 4, ...
                'MarkerEdgeColor', 'k', ...
                'MarkerFaceColor', 'none');

plot(t, dn1_out, 'Color', 'b', 'LineWidth', 6,...
                'MarkerEdgeColor', 'b', ...
                'MarkerFaceColor', 'none');

plot(t, dn2_out, 'Color', 'k', 'LineWidth', 6,  ...
                'MarkerEdgeColor', 'k', ...
                'MarkerFaceColor', 'none');

plot(t, dn4_out, 'Color', 'm', 'LineWidth', 6,  ...
                'MarkerEdgeColor', 'm', ...
                'MarkerFaceColor', 'none');
            
plot(t, dn8_out, 'Color', 'y', 'LineWidth', 6,  ...
                'MarkerEdgeColor', 'y', ...
                'MarkerFaceColor', 'none');
    
plot(t, dn16_out, 'Color', 'g', 'LineWidth', 6, ...
                'MarkerEdgeColor', 'g', ...
                'MarkerFaceColor', 'none');

plot(t, dn32_out, 'Color', 'c', 'LineWidth', 6,  ...
                'MarkerEdgeColor', 'c', ...
                'MarkerFaceColor', 'none');

plot(t, dn64_out, 'Color', 'r', 'LineWidth', 6, ...
                'MarkerEdgeColor', 'r', ...
                'MarkerFaceColor', 'none');

plot(t, dn128_out, 'Color', 'b', 'LineWidth', 2, ...
                'MarkerEdgeColor', 'b', ...
                'MarkerFaceColor', 'none');


plot(t, dn256_out, 'Color', 'k', 'LineWidth', 2, ...
                'MarkerEdgeColor', 'k', ...
                'MarkerFaceColor', 'none');
            
plot(t, dn512_out, 'Color', 'm', 'LineWidth', 2, ...
                'MarkerEdgeColor', 'm', ...
                'MarkerFaceColor', 'none');
            
plot(t, dn1024_out, 'Color', 'y', 'LineWidth', 2,  ...
                'MarkerEdgeColor', 'y', ...
                'MarkerFaceColor', 'none');
plot(t, dn2048_out, 'Color', 'b', 'LineWidth', 2, ...
                'MarkerEdgeColor', 'b', ...
                'MarkerFaceColor', 'none');


plot(t, dn4096_out, 'Color', 'k', 'LineWidth', 2, ...
                'MarkerEdgeColor', 'k', ...
                'MarkerFaceColor', 'none');
            
plot(t, dn8192_out, 'Color', 'm', 'LineWidth', 2, ...
                'MarkerEdgeColor', 'm', ...
                'MarkerFaceColor', 'none');
            
plot(t, dn16384_out, 'Color', 'y', 'LineWidth', 2,  ...
                'MarkerEdgeColor', 'y', ...
                'MarkerFaceColor', 'none');
plot(t, dn32768_out, 'Color', 'c', 'LineWidth', 3, ...
                'MarkerEdgeColor', 'c', ...
                'MarkerFaceColor', 'none');
plot(t, dn65536_out, 'Color', 'r', 'LineWidth', 3, ...
                'MarkerEdgeColor', 'r', ...
                'MarkerFaceColor', 'none');
plot(t, dn131072_out, 'Color', 'b', 'LineWidth', 3, ...
                'MarkerEdgeColor', 'b', ...
                'MarkerFaceColor', 'none');
plot(t, dn262144_out, 'Color', 'g', 'LineWidth', 1, ...
                'MarkerEdgeColor', 'g', ...
                'MarkerFaceColor', 'none');
plot(t, dn524288_out, 'Color', 'k', 'LineWidth', 1, ...
                'MarkerEdgeColor', 'k', ...
                'MarkerFaceColor', 'none');
plot(t, dn1048576_out, 'Color', 'm', 'LineWidth', 1);


            
%set(YL, fontProps)
legend('dn', 'dn1out', 'dn2out', 'dn4out', 'dn8out', 'dn16out', 'dn32out', 'dn64out',...
    'dn128out', 'dn256out', 'dn512out', 'dn1024out','dn2048out', 'dn4096out', 'dn8192out',...
    'dn16384out', 'dn32768out', 'dn65536out', 'dn131072out','dn262144out', 'dn524288out', 'dn1048576out')
set(legend, fontProps)
     
Title_dn=title('added particles in each step');
set(Title_dn, fontProps)
XL=xlabel('time (s)'); 
set(XL, fontProps)
YL=ylabel('dn'); 

    end 
end 
%% 
%corrected number of partices (assuming all are of equal size)- calculated
%by mass balance 

for plot_norg =plotpaa_norg
    if plot_norg==1

Figure_norg= figure(15); %Name of figure

%Use of set statement to the define properties for the figure.
set(Figure_norg, figProps)
%Use a set statement to define properties for fonts.
set(axes, fontProps)
%Set limits in the "x" coordinate, place boarder around plot, and use
%gridlines.
xlim([0 1e5])
ylim([1 1e23]);

ax = gca;
ax.YAxis.Scale = 'log';
yticks([ 10^03 10^04 10^05 10^06 10^07 10^08 10^09 10^10 10^11 10^12 10^13 10^14 10^15 ...
    10^16 10^17 10^18 10^19 10^20 10^21 10^22 10^23 10^24 10^25 10^26 10^27])
yticklabels({'10^3','10^4','10^5','10^6','10^7','10^8','10^9','10^1^0','10^1^1','10^1^2','10^1^3','10^1^4',...
    '10^1^5','10^1^6','10^1^7','10^1^8','10^1^9','10^2^0','10^2^1','10^2^2','10^2^3','10^2^4','10^2^5','10^2^6','10^2^7'})

ax = gca;
ax.XAxis.Scale = 'log';
xticks([10^-30 10^-20 10^-10 10^00 10^10 10^20 10^30 10^40])
xticklabels({'10^-^3^0','10^-^2^0','10^-^1^0','10^0','10^1^0','10^2^0','10^3^0','10^4^0'})

%Plot the function

hold on
box on
grid on

            
plot(t, n1c, 'Color', 'b', 'LineWidth', 7, 'Marker', 'o', ...
                'MarkerEdgeColor', 'b', ...
                'MarkerFaceColor', 'none');
            
plot(t, n2c, 'Color', 'g', 'LineWidth', 7,  ...
                'MarkerEdgeColor', 'g', ...
                'MarkerFaceColor', 'none');
            
plot(t, n4c, 'Color', 'y', 'LineWidth', 7, ...
                'MarkerEdgeColor', 'y', ...
                'MarkerFaceColor', 'none');

plot(t, n8c, 'Color', 'm', 'LineWidth', 5, ...
                'MarkerEdgeColor', 'm', ...
                'MarkerFaceColor', 'none');

            
plot(t, n16c, 'Color', 'k', 'LineWidth', 5, ...
                'MarkerEdgeColor', 'k', ...
                'MarkerFaceColor', 'none');

plot(t, n32c, 'Color', 'c', 'LineWidth', 3, ...
                'MarkerEdgeColor', 'c', ...
                'MarkerFaceColor', 'none');
            
plot(t, n64c, 'Color', 'r', 'LineWidth', 3,  ...
               'MarkerEdgeColor', 'r', ...
               'MarkerFaceColor', 'none');
  
plot(t, n128c, 'Color', 'b', 'LineWidth', 1,  ...
                'MarkerEdgeColor', 'b', ...
                'MarkerFaceColor', 'none');
            
plot(t, n256c, 'Color', 'g', 'LineWidth', 1, ...
                'MarkerEdgeColor', 'g', ...
                'MarkerFaceColor', 'none');

plot(t, n512c, 'Color', 'm', 'LineWidth', 1, ...
                'MarkerEdgeColor', 'g', ...
                'MarkerFaceColor', 'none');
            
plot(t, n1024c, 'Color', 'y', 'LineWidth', 1,  ...
                'MarkerEdgeColor', 'y', ...
                'MarkerFaceColor', 'none');
            
plot(t, n2048c, 'Color', 'r', 'LineWidth', 1,  ...
                'MarkerEdgeColor', 'r', ...
                'MarkerFaceColor', 'none');
            
plot(t, n4096c, 'Color', 'g', 'LineWidth', 1, ...
                'MarkerEdgeColor', 'g', ...
                'MarkerFaceColor', 'none');

plot(t, n8192c, 'Color', 'm', 'LineWidth', 1, ...
                'MarkerEdgeColor', 'g', ...
                'MarkerFaceColor', 'none');
            
plot(t, n16384c, 'Color', 'y', 'LineWidth', 1,  ...
                'MarkerEdgeColor', 'y', ...
                'MarkerFaceColor', 'none');
            
plot(t, n32768c, 'Color', 'c', 'LineWidth', 3, ...
                'MarkerEdgeColor', 'c', ...
                'MarkerFaceColor', 'none');
plot(t, n65536c, 'Color', 'r', 'LineWidth', 3, ...
                'MarkerEdgeColor', 'r', ...
                'MarkerFaceColor', 'none');
plot(t, n131072c, 'Color', 'b', 'LineWidth', 3, ...
                'MarkerEdgeColor', 'b', ...
                'MarkerFaceColor', 'none');
plot(t, n262144c, 'Color', 'g', 'LineWidth', 1, ...
                'MarkerEdgeColor', 'g', ...
                'MarkerFaceColor', 'none');
plot(t, n524288c, 'Color', 'k', 'LineWidth', 1, ...
                'MarkerEdgeColor', 'k', ...
                'MarkerFaceColor', 'none');
plot(t, n1048576c, 'Color', 'm', 'LineWidth', 1);
  
plot(t, n_tV2, 'Color', 'k', 'LineWidth', 5, ...
                'MarkerEdgeColor', 'k', ...
                'MarkerFaceColor', 'none');

plot(t, n_tot_c, 'Color', 'c', 'LineWidth', 3, ...
                'MarkerEdgeColor', 'c', ...
                'MarkerFaceColor', 'none');

plot(t, n_tot_r, 'Color', 'r', 'LineWidth', 1, ...
                'MarkerEdgeColor', 'c', ...
                'MarkerFaceColor', 'none');
            
            
%set(YL, fontProps)
legend('n_g_1', 'n_g_2', 'n_g_4','n_g_8', 'n_g_1_6', 'n_g_3_2', 'n_g_6_4', 'n_g_1_2_8', 'n_g_2_5_6', 'n_g_5_1_2', 'n_g_1_0_2_4',...
         'n_g_2_0_4_8', 'n_g_4_0_9_6', 'n_g_8_1_9_2', 'n_g_1_6_3_8_4', 'n_g_3_2_7_6_8','n_g_6_5_5_3_6','n_g_1_3_1_0_7_2','n_g_2_6_2_1_4_4',...
           'n_g_5_2_4_2_8_8','n_g_1_0_4_8_5_7_6', 'n_a_g_g', 'n_t_o_t_c', 'n_t_o_t_r') %, 'n_r8', 'n_r16', 'n_r32','n_r64','n_r128'
set(legend, fontProps)

Title_n_c=title('Averaged number of particles in each group');
set(Title_n_c, fontProps)
XL=xlabel('time (s)'); 
set(XL, fontProps)
%YL=ylabel('Number concentration (-)'); 

    end 
end 

%% 
%change in deposition rate 

for plot_Jpp=plotpaa_Jpp
    if plot_Jpp==1
        
Figure_Jpp = figure(16); %Name of figure

%Use of set statement to the define properties for the figure.
set(Figure_Jpp, figProps)
%Use a set statement to define properties for fonts.
set(axes, fontProps)
%Set limits in the "x" coordinate, place boarder around plot, and use
%gridlines.
xlim([0 1e-1])
%ylim([1 1e22]);

%ax = gca;
%ax.YAxis.Scale = 'log';
%yticks([ 10^-05 10^-04 10^-03 10^-02 10^-01 10^0 10^1 10^2 10^2 10^4 10^5 10^6 10^7 10^8 10^9])
%yticklabels({'10^-^5','10^-^4','10^-^3','10^-^2','10^-^1','10^0','10^1','10^2','10^3','10^4', '10^5',...
 %           '10^6','10^7','10^8','10^9'})  

%ax = gca;
%ax.XAxis.Scale = 'log';
%xticks([10^-30 10^-20 10^-10 10^00 10^10 10^20 10^30 10^40])
%xticklabels({'10^-^3^0','10^-^2^0','10^-^1^0','10^0','10^1^0','10^2^0','10^3^0','10^4^0'})

%Plot the function

hold on
box on
grid on

plot(t, J_pp, 'Color', 'r', 'LineWidth', 2, 'Marker', 'o', ...
                'MarkerEdgeColor', 'r', ...
                'MarkerFaceColor', 'none');
plot(t, l1_test, 'Color', 'r', 'LineWidth', 2, ...
                'MarkerEdgeColor', 'r', ...
                'MarkerFaceColor', 'none');
plot(t, l2_test, 'Color', 'y', 'LineWidth', 2, ...
                'MarkerEdgeColor', 'y', ...
                'MarkerFaceColor', 'none');
plot(t, l3_test, 'Color', 'r', 'LineWidth', 2, ...
                'MarkerEdgeColor', 'r', ...
                'MarkerFaceColor', 'none');
plot(t, l4_test, 'Color', 'y', 'LineWidth', 2, ...
                'MarkerEdgeColor', 'y', ...
                'MarkerFaceColor', 'none');
            
%set(YL, fontProps)
legend('Jpp')
set(legend, fontProps)
     
Title_Jpp=title('Deposition rate with time');
set(Title_Jpp, fontProps)
XL=xlabel('time (s)'); 
set(XL, fontProps)
YL=ylabel('Deposition rate (mg/m2s)'); 

    end 
end 

%% 
%Dimensionless deposition rate

for plot_mdep=plotpaa_mdep
    if plot_mdep==1
        
Figure_m_dep = figure(17); %Name of figure

%Use of set statement to the define properties for the figure.
set(Figure_m_dep, figProps)
%Use a set statement to define properties for fonts.
set(axes, fontProps)
%Set limits in the "x" coordinate, place boarder around plot, and use
%gridlines
%xlim([0 0.2])
%ylim([1 1e22]);

%ax = gca;
%ax.YAxis.Scale = 'log';
%yticks([ 10^-05 10^-04 10^-03 10^-02 10^-01 10^0 10^1 10^2 10^2 10^4 10^5 10^6 10^7 10^8 10^9])
%yticklabels({'10^-^5','10^-^4','10^-^3','10^-^2','10^-^1','10^0','10^1','10^2','10^3','10^4', '10^5',...
 %           '10^6','10^7','10^8','10^9'})  

ax = gca;
ax.XAxis.Scale = 'log';
xticks([10^-30 10^-20 10^-10 10^00 10^10 10^20 10^30 10^40])
xticklabels({'10^-^3^0','10^-^2^0','10^-^1^0','10^0','10^1^0','10^2^0','10^3^0','10^4^0'})

%Plot the function

hold on
box on
grid on

            
plot(l, m_tot_dep2_pp, 'Color', 'b', 'LineWidth', 4, 'Marker', 'o', ...
                'MarkerEdgeColor', 'b', ...
                'MarkerFaceColor', 'none');
plot(l, m_tot_dep2_w, 'Color', 'b', 'LineWidth', 4, 'Marker', 'o', ...
                'MarkerEdgeColor', 'b', ...
                'MarkerFaceColor', 'none');
      
plot(l, l1_test, 'Color', 'r', 'LineWidth', 2, ...
                'MarkerEdgeColor', 'r', ...
                'MarkerFaceColor', 'none');
plot(l, l2_test, 'Color', 'y', 'LineWidth', 2, ...
                'MarkerEdgeColor', 'y', ...
                'MarkerFaceColor', 'none');
plot(l, l3_test, 'Color', 'r', 'LineWidth', 2, ...
                'MarkerEdgeColor', 'r', ...
                'MarkerFaceColor', 'none');
plot(l, l4_test, 'Color', 'y', 'LineWidth', 2, ...
                'MarkerEdgeColor', 'y', ...
                'MarkerFaceColor', 'none');


%set(YL, fontProps)
legend('m_t_o_t_d', 'l1_t', 'l2_t', 'l3_t', 'l4_t')
set(legend, fontProps)
     
Title_m_dep_tot=title('Mass deposited in test section as a function of time');
set(Title_m_dep_tot, fontProps)
XL=xlabel('Length (m))'); 
set(XL, fontProps)
YL=ylabel('Depostion (mg/h)'); 

    end 
end 

%% 
%total deposited per length given in cncentration 

for plot_cdep=plotpaa_cdep
    if plot_cdep==1
        
Figure_c_dep_tot = figure(18); %Name of figure

%Use of set statement to the define properties for the figure.
set(Figure_c_dep_tot, figProps)
%Use a set statement to define properties for fonts.
set(axes, fontProps)
%Set limits in the "x" coordinate, place boarder around plot, and use
%gridlines.
xlim([0 0.2])
%ylim([1 1e22]);

%ax = gca;
%ax.YAxis.Scale = 'log';
%yticks([ 10^-05 10^-04 10^-03 10^-02 10^-01 10^0 10^1 10^2 10^2 10^4 10^5 10^6 10^7 10^8 10^9])
%yticklabels({'10^-^5','10^-^4','10^-^3','10^-^2','10^-^1','10^0','10^1','10^2','10^3','10^4', '10^5',...
 %           '10^6','10^7','10^8','10^9'})  

%ax = gca;
%ax.XAxis.Scale = 'log';
%xticks([10^-30 10^-20 10^-10 10^00 10^10 10^20 10^30 10^40])
%xticklabels({'10^-^3^0','10^-^2^0','10^-^1^0','10^0','10^1^0','10^2^0','10^3^0','10^4^0'})

%Plot the function

hold on
box on
grid on

plot(l, c_dep_tot_pp, 'Color', 'b', 'LineWidth', 4, 'Marker', 'o', ...     %mg/kg
                'MarkerEdgeColor', 'b', ...
                'MarkerFaceColor', 'none');
plot(l, l1_test, 'Color', 'r', 'LineWidth', 2, ...
                'MarkerEdgeColor', 'r', ...
                'MarkerFaceColor', 'none');
plot(l, l2_test, 'Color', 'y', 'LineWidth', 2, ...
                'MarkerEdgeColor', 'y', ...
                'MarkerFaceColor', 'none');
plot(l, l3_test, 'Color', 'r', 'LineWidth', 2, ...
                'MarkerEdgeColor', 'r', ...
                'MarkerFaceColor', 'none');
plot(l, l4_test, 'Color', 'y', 'LineWidth', 2, ...
                'MarkerEdgeColor', 'y', ...
                'MarkerFaceColor', 'none');
            
%set(YL, fontProps)
legend('c_d_e_p', 'l1_t', 'l2_t', 'l3_t', 'l4_t')
set(legend, fontProps)
     
Title_c_dep_tot=title('Deposited mass per kg water ');
set(Title_c_dep_tot, fontProps)
XL=xlabel('Length (m)'); 
set(XL, fontProps)
YL=ylabel('Depostion (mg/kg)'); 

    end 
end 

%% 
%mass deposted in test section 

for plot_mtestsect=plotpaa_mtestsect
    if plot_mtestsect==1

Figure_m_testsect = figure(19); %Name of figure

%Use of set statement to the define properties for the figure.
set(Figure_m_testsect, figProps)
%Use a set statement to define properties for fonts.
set(axes, fontProps)
%Set limits in the "x" coordinate, place boarder around plot, and use
%gridlines.
xlim([0 0.2])
%ylim([1 1e22]);

%ax = gca;
%ax.YAxis.Scale = 'log';
%yticks([ 10^-05 10^-04 10^-03 10^-02 10^-01 10^0 10^1 10^2 10^2 10^4 10^5 10^6 10^7 10^8 10^9])
%yticklabels({'10^-^5','10^-^4','10^-^3','10^-^2','10^-^1','10^0','10^1','10^2','10^3','10^4', '10^5',...
 %           '10^6','10^7','10^8','10^9'})  

%ax = gca;
%ax.XAxis.Scale = 'log';
%xticks([10^-30 10^-20 10^-10 10^00 10^10 10^20 10^30 10^40])
%xticklabels({'10^-^3^0','10^-^2^0','10^-^1^0','10^0','10^1^0','10^2^0','10^3^0','10^4^0'})

%Plot the function

hold on
box on
grid on

plot(t, m_tot_dep_pp, 'Color', 'b', 'LineWidth', 6, ...
                'MarkerEdgeColor', 'b', ...
                'MarkerFaceColor', 'none');
plot(t, m_tot_dep_w, 'Color', 'r', 'LineWidth', 6, ...
                'MarkerEdgeColor', 'r', ...
                'MarkerFaceColor', 'none');
%plot(t, m_tot_test_a_pp, 'Color', 'g', 'LineWidth', 4, ...
 %               'MarkerEdgeColor', 'g', ...
  %              'MarkerFaceColor', 'none');
%plot(t, m_tot_test_a_fa, 'Color', 'g', 'LineWidth', 4, ...
 %               'MarkerEdgeColor', 'g', ...
  %              'MarkerFaceColor', 'none');
%plot(t, m_tot_test_c_pp, 'Color', 'm', 'LineWidth', 4, ...
 %               'MarkerEdgeColor', 'm', ...
  %              'MarkerFaceColor', 'none');
%plot(t, m_tot_test_c_fa, 'Color', 'g', 'LineWidth', 4, ...
 %               'MarkerEdgeColor', 'g', ...
  %              'MarkerFaceColor', 'none');
plot(t, m_tot_test1_pp, 'Color', 'c', 'LineWidth', 4, ...
                'MarkerEdgeColor', 'c', ...
                'MarkerFaceColor', 'none');
plot(t, m_tot_test1_w, 'Color', 'k', 'LineWidth', 4, ...
                'MarkerEdgeColor', 'k', ...
                'MarkerFaceColor', 'none');
plot(t, m_tot_test2_pp, 'Color', 'b', 'LineWidth', 2, ...
                'MarkerEdgeColor', 'b', ...
                'MarkerFaceColor', 'none');
plot(t, m_tot_test2_w, 'Color', 'r', 'LineWidth', 2, ...
                'MarkerEdgeColor', 'r', ...
                'MarkerFaceColor', 'none');
%plot(t, m_tot_test0, 'Color', 'r', 'LineWidth', 2, ...
 %               'MarkerEdgeColor', 'r', ...
  %              'MarkerFaceColor', 'none');
%plot(t, l_test, 'Color', 'r', 'LineWidth', 1, ...
 %               'MarkerEdgeColor', 'r', ...
  %             'MarkerFaceColor', 'none');
%plot(t, ll_test, 'Color', 'y', 'LineWidth', 1, ...
 %               'MarkerEdgeColor', 'y', ...
  %              'MarkerFaceColor', 'none');
            
%set(YL, fontProps)
legend('mpp','mfa','mtest1pp','mtest1fa','mtest2pp','mtest2fa')
set(legend, fontProps)
     
Title_m_testsect=title('Total deposited mass in the test section per hour as a function of time');
set(Title_m_testsect, fontProps)
XL=xlabel('time (s)'); 
set(XL, fontProps)
YL=ylabel('Depostion (mg/hour)'); 

    end 
end 

%% 
%concentration profile matrix
for plot_Xcaa=plotpaa_Xcaa
    if plot_Xcaa==1
        
Figure_Xcaa = figure(22); %Name of figure

%Use of set statement to the define properties for the figure.
set(Figure_Xcaa, figProps)
%Use a set statement to define properties for fonts.
set(axes, fontProps)
%Set limits in the "x" coordinate, place boarder around plot, and use
%gridlines.
%xlim([0 1e5])
%ylim([-1 300]);


ax = gca;
ax.XAxis.Scale = 'log';
xticks([10^-30 10^-20 10^-10 10^00 10^10 10^20 10^30 10^40])
xticklabels({'10^-^3^0','10^-^2^0','10^-^1^0','10^0','10^1^0','10^2^0','10^3^0','10^4^0'})

%Plot the function

hold on
box on
grid on

plot(distra, distca, 'Color', 'b', 'LineWidth', 2, 'Marker', 'o', ... %concentration of dissolved particles in the steam 
                'MarkerEdgeColor', 'b', ...
                'MarkerFaceColor', 'none');
plot(distrc, distcc, 'Color', 'r', 'LineWidth', 2, 'Marker', 'o', ... %concentration of dissolved particles in the steam 
                'MarkerEdgeColor', 'r', ...
                'MarkerFaceColor', 'none');
plot(distro, distco, 'Color', 'g', 'LineWidth', 2, 'Marker', 'o', ... %concentration of dissolved particles in the steam 
                'MarkerEdgeColor', 'g', ...
                'MarkerFaceColor', 'none');

legend('Test section 1', 'Test section 2','Orifice entrance');
Title_Xcaa=title('Concentration distribution');
set(Title_Xcaa, fontProps)
XL=xlabel('Radius(m)'); 
set(XL, fontProps)
YL=ylabel('Concentration (mg/kg)'); 
set(YL, fontProps)
set(legend, fontProps)

    end 
end

%% number of particles plot linpece matrix
for plot_Xcadist=plotpaa_Xcadist
    if plot_Xcadist==1

        Figure_Xca=figure(23);

N = 1;
C = linspecer(N);

loglog(distra,distca,'color', C(1,:),'marker','o','LineStyle',':','LineWidth',4); 


hold on
grid on 

set(gca,'fontsize', 18);
p = p*10;
xlabel('radius')
ylabel('Concentration in each group')
title('Concentration distribution', 'FontSize',18);


legend ('c');

    end
end

%% 
%Xper plot

for plot_Xcper=plotpaa_Xcper
    if plot_Xcper==1
        
Figure_Xcper = figure(24); %Name of figure

%Use a set statement to define properties for fonts.
set(axes, fontProps)
%Set limits in the "x" coordinate, place boarder around plot, and use
%gridlines.
%xlim([0 1e50])
ylim([-0.1 1.1]);

%ax = gca;
%ax.YAxis.Scale = 'log';
%yticks([ 10^-30 10^-20 10^-10 10^00 10^10 10^20 10^30 ])
%yticklabels({'10E-30','10E-20','10E-10','10E00','10E10','10E20','10E30'})  


ax = gca;
ax.XAxis.Scale = 'log';
xticks([10^-30 10^-20 10^-10 10^00 10^10 10^20 10^30 10^40])
xticklabels({'10^-^3^0','10^-^2^0','10^-^1^0','10^0','10^1^0','10^2^0','10^3^0','10^4^0'})

%Plot the function

hold on
box on
grid on

plot(t, Xcpertot, 'Color', 'k', 'LineWidth', 7);               %concentration of dissolved particles in the steam 

for j = 1:N2
    plot(t,Xcper(j,:), 'Color', 'b', 'LineWidth', 1)
end
         
%Title_c=title('Fraction of solidified concentration in each particle group');
%set(Title_Xcper, fontProps)
XL=xlabel('time (s)'); 
set(XL, fontProps)
YL=ylabel('Fraction'); 
set(YL, fontProps)
legend('Total fraction of particles')
set(legend, fontProps)


    end 
end

%% %Vd comparison plot3- test result
N=8;
C = linspecer(N);

for plot_Vd3=plotpaa_Vd3
    if plotpaa_Vd3==1
Figure_V_dep_t3 = figure(31); %Name of figure

%Use of set statement to the define properties for the figure.
set(Figure_V_dep_t3, figProps)
%Use a set statement to define properties for fonts.
set(axes, fontProps)
%Set limits in the "x" coordinate, place boarder around plot, and use
%gridlines.
xlim([0 1e1])
%ylim([1 1e22]);

ax = gca;
ax.YAxis.Scale = 'log';
yticks([ 10^-09 10^-08 10^-07 10^-06 10^-05 10^-04 10^-03 10^-02 10^-01 10^0 10^01 10^02 10^03 ])
yticklabels({'10^-^9','10^-^8','10^-^7','10^-^6','10^-^5','10^-^4','10^-^3','10^-^2','10^-^1','10^0','10^1','10^2','10^3'})  

ax = gca;
ax.XAxis.Scale = 'log';
xticks([10^-08 10^-07 10^-06 10^-05 10^-04 10^-03 10^-02 10^-01 10^0])
xticklabels({'10^-^8','10^-^7','10^-^6','10^-^5','10^-^4','10^-^3','10^-^2','10^-^1','10^0'})

%Plot the function

hold on
box on
grid on

plot(tau_p_plus, Vd_p_wood2, 'color',C(2,:), 'LineWidth', 4, 'Marker', '+', ...
                'MarkerEdgeColor', C(2,:), ...
                'MarkerFaceColor', 'none');
plot(tau_p_plus, V_pp_plot3, 'color',C(3,:), 'LineWidth', 3, 'Marker', 'none', ...
                'MarkerEdgeColor', C(3,:), ...
                'MarkerFaceColor', 'none');
%plot(tau_p_plus, Vd_p_wood2, 'color',C(1,:), 'LineWidth', 1, 'Marker', '+', ...
 %               'MarkerEdgeColor', C(1,:), ...
%  %              'MarkerFaceColor', 'none');
%plot(tau_p_plus, V_fa_plot2, 'color',C(6,:), 'LineWidth', 2, 'Marker', '+', ...
 %               'MarkerEdgeColor', C(6,:), ...
  %              'MarkerFaceColor', 'none');
%plot(tau_p_plus, Vd_p_fan, 'color',C(7,:), 'LineWidth', 2, 'Marker', '+', ...
 %               'MarkerEdgeColor', C(7,:), ...
  %              'MarkerFaceColor', 'none');
plot(tau_p_plus_ab_SEM,Vd_plus_ab_test,'linestyle','none','color',C(4,:),'Marker', 'o','LineWidth',4)
plot(tau_p_plus_cd_SEM,Vd_plus_cd_test,'linestyle','none','color',C(4,:),'Marker', 'o','LineWidth',4)
plot(tau_p_plus_a_calc,Vd_calc_a,'linestyle','none','color',C(6,:),'Marker', 'square','LineWidth',4)
plot(tau_p_plus_c_calc,Vd_calc_c,'linestyle','none','color',C(6,:),'Marker', 'square','LineWidth',4)
plot(tau_test_ab_maxmin,Vd_test_ab_maxmin,'linestyle','-','color',C(5,:),'Marker', 'o','LineWidth',1)
plot(tau_test_cd_maxmin,Vd_test_cd_maxmin,'linestyle','-','color',C(5,:),'Marker', 'o','LineWidth',1)
plot(tau_uncert_cd,Vd_tau_cd_maxmin,'linestyle','--','color',C(7,:),'Marker', 'square','LineWidth',1)
plot(tau_uncert_ab,Vd_tau_ab_maxmin,'linestyle','--','color',C(7,:),'Marker', 'square','LineWidth',1)


grid off

%set(YL, fontProps)
legend('Wood (1981)','Popov and Petukhov','Test section 1 experimental results','Test section 2 experimental results','Test section 1- Modelled deposition','Test section 2-Modelled deposition',...
    'Test section 1-uncertainty band deposition velocity', 'Test section 2 -uncertainty band deposition velocity', 'Test section 1- Estimated size range based on paritcle count', 'Test section 2- size range based on paritcle count')
set(legend, fontProps)
     
Title_V_dep_t3=title('Dimensionless deposition rate as a function of dimensionless particle relaxation time');
%set(Title_V_dep, fontProps)
XL=xlabel('Dimensionless particle relaxation time, \tau_p^+(-)'); 
set(XL, fontProps)
YL=ylabel('Dimensionless deposition velocity, V_d^+ (-)'); 

    end 
end 

