
%deposition function_wood

function OUT1=deposition_function_FA(IN1,IN2,IN3,IN4,IN5)
%IN1 is desired number of grid points N1 
%IN2 is the diameter of the particles
%IN3 is the pressure p
%IN4 is the Temperature T 
%IN5 is flow rate Q1
%% 

Nd=IN1;
p=IN3;
T=IN4;

%% %%
%calculated constants
visc = IAPWS_IF97('mu_pT',(p/10),T);                         %mu  - [Pa*s] viscosity mu_pT, IAPWS_IF97('mu_pT',p,T);
vs=IAPWS_IF97('v_pT',(p/10),T);                                 %spesific volume m3/kg
roW=1/vs;                                                          %density kg/m3
kinvisc=visc/roW;                                               %kinematic viscosity m2/s
roSiA=2196;                 %Amorphous silica density (kg/m3)

D_pipe = 0.00138;            %Test chamber diameter (m)
kb=1.3e-23;                 %boltzmann konstant J/K
V1 = IN5/roW;                                               %volumetric flow rate (m3/s)
A_cross = (pi*(D_pipe/2)^2);  %-(n_rods*pi*(D_rod/2)^2);       %cross sectional area of pipe (m2)
v = V1/A_cross;                                              % Velocity (m/s) calculated based on test chamber diameter of D
D_hydr=D_pipe;     %(((pi*(D_pipe/2)^2)*L)-(n_rods*((pi*(D_rod/2)^2)*L)))/((2*pi*(D_pipe/2)*L)+(2*n_rods*pi*(D_rod/2)*L))              %hydraulic diameter (flow volume/wetted area)
Re = v*(D_hydr)/kinvisc;       %Rynolds number (-)
l_char=D_pipe;

h_ent=IAPWS_IF97('h_pT',(p/10),T); %enthalpy, h [kJ/kg]
cp=IAPWS_IF97('cp_ph',(p/10),h_ent); %Heat capasity at constant pressure [kJ/kg/K]
k_th=IAPWS_IF97('k_pT',(p/10),T);  %Thermal conductivity [W/m/K]

Pr=cp*1000*visc/k_th; % (-) OK dim

frict=0.0791/(Re^0.25);         %friction factor- Fanning 
u_frict=v*sqrt(frict/2);           %frictional velocity (m/s)

%% Particle relaxation time

l_s = 0.0664 * 10^-6 *(101/p)*(T/293)*((1+(110)/(293))/(1+(110)/(T))); % Crowe

Kn = l_s/(IN2); % Knudsen number
Cc = 1 + Kn*(2.514+0.8*exp(-0.55/Kn)); % Cunningham slip correction factor
%Cc = 1 + Kn.*(2.34 + 1.05 .* exp(-0.39./Kn)); % Tandberg, uses 0.5*Kn

tau_p=(roSiA*(IN2)^2*Cc)/(18*visc); % Particle inertia relaxation time
tau_p_plus=tau_p*u_frict^2/kinvisc; % Dimensionless relaxation time

D_b = (kb*T*Cc)/(3*pi*visc*(IN2)); % Brownian diffusion coefficient [m^2/s]

Sc_p = kinvisc/D_b; % Particle schmidt number [-]

%% pp correlation

f_pp=(3.64*log10(Re)-3.28)^(-2); %factor (-) From correlatation

% heat and mass transfer analogy/ Popov- Pethukov and Coldburn correlation for heat ans mass transfer 
Nu_pp=(f_pp/2)*Re*Pr/((1+(13.6*f_pp))+(11.7+1.8*Pr^(-1/3))*((f_pp/2)^(1/2))*((Pr^(3/2))-1));
Nu_c=0.023*Re^(0.8)*(Pr^(1/3));

Sh_c=Nu_c*(Sc_p.^(1/3))/(Pr^(1/3));
Sh_pp=Nu_pp*(Sc_p.^(1/3))/(Pr^(1/3));

h_c_plot=Sh_c.*D_b./l_char; 
h_pp_plot=Sh_pp.*D_b./l_char;           %convective mass transfer rate (m/s)

V_pp_plot=h_pp_plot/u_frict;
V_c_plot=h_c_plot/u_frict;

OUT1=V_pp_plot;