
%deposition function_wood

function OUT1=deposition_function_FA(IN1,IN2,IN3,IN4,IN5)
%IN1 is desired number of grid points N1 
%IN2 is the diameter of the particles
%IN3 is the pressure p
%IN4 is the Temperature T 
%IN5 is flow rate Q1
%% 

Nd=IN1;
p=IN3;
T=IN4;

%% %%
%calculated constants
visc = IAPWS_IF97('mu_pT',(p/10),T);                         %mu  - [Pa*s] viscosity mu_pT, IAPWS_IF97('mu_pT',p,T);
vs=IAPWS_IF97('v_pT',(p/10),T);                                 %spesific volume m3/kg
roW=1/vs;                                                          %density kg/m3
kinvisc=visc/roW;                                               %kinematic viscosity m2/s
roSiA=2196;                 %Amorphous silica density (kg/m3)

D_pipe = 0.00138;            %Test chamber diameter (m)
kb=1.3e-23;                 %boltzmann konstant J/K
V1 = IN5/roW;                                               %volumetric flow rate (m3/s)
A_cross = (pi*(D_pipe/2)^2);  %-(n_rods*pi*(D_rod/2)^2);       %cross sectional area of pipe (m2)
v = V1/A_cross;                                              % Velocity (m/s) calculated based on test chamber diameter of D
D_hydr=D_pipe;     %(((pi*(D_pipe/2)^2)*L)-(n_rods*((pi*(D_rod/2)^2)*L)))/((2*pi*(D_pipe/2)*L)+(2*n_rods*pi*(D_rod/2)*L))              %hydraulic diameter (flow volume/wetted area)
Re = v*(D_hydr)/kinvisc;       %Rynolds number (-)

frict=0.0791/(Re^0.25);         %friction factor- Fanning 
u_frict=v*sqrt(frict/2);           %frictional velocity (m/s)

%% Particle relaxation time

l_s = 0.0664 * 10^-6 *(101/p)*(T/293)*((1+(110)/(293))/(1+(110)/(T))); % Crowe

Kn = l_s/(IN2); % Knudsen number
Cc = 1 + Kn*(2.514+0.8*exp(-0.55/Kn)); % Cunningham slip correction factor
%Cc = 1 + Kn.*(2.34 + 1.05 .* exp(-0.39./Kn)); % Tandberg, uses 0.5*Kn

tau_p=(roSiA*((IN2)^2)*Cc)/(18*visc); % Particle inertia relaxation time
tau_p_plus=tau_p*(u_frict^2)/kinvisc; % Dimensionless relaxation time

D_b = (kb*T*Cc)/(3*pi*visc*(IN2)); % Brownian diffusion coefficient [m^2/s]

Sc_p = kinvisc/D_b; % Particle schmidt number [-]

%% Wood (1981)

tau_p_wood = tau_p_plus;
    if tau_p_wood < 20
     Vd_p_wood = 0.057*(Sc_p)^(-2/3) + 4.5e-4*tau_p_wood^2; 
    else
        Vd_p_wood = 0.14;
    end

OUT1=Vd_p_wood;